*This do-file cleans the hh members dataset and generates variables used for the analysis

*Load hhm data
use "${gsdData}/1-CleanInput/hhm.dta", clear
*Temporarily rename vars for recoding
rename (B_3_ishead	BB_1_presence	BB_2_gender	BB_3_relation	BB_4_age	BB_4_age_dk	BE_2_edu_current	BE_3_edu_ever	BE_4_edu_level	BE_5_occ_lev1	BE_1_1_read	BE_1_2_write	BE_5_1_occ_clerq	BE_5_1_occ_craft	BE_5_1_occ_elem	BE_5_1_occ_forces	BE_5_1_occ_mgr	BE_5_1_occ_plant	BE_5_1_occ_prof	BE_5_1_occ_service	BE_5_1_occ_skilled	BE_5_1_occ_tech	BM_1_migr_never	BM_2_migr_time_dk	BM_2_migr_time_m	BM_2_migr_time_y	BM_3_migr_from	BM_2_1_migr_oscillation	BW_1_empl_appr12m	BW_2_empl_farm12m	BW_3_empl_inc12m	BW_4_empl_bus12m	BW_5_empl_fhelp12m	BW_6_empl_primary12m	BW_7_empl_active7d	BW_8_empl_primary7d	BW_9_empl7d_inactive	BW_10_empl7d_temp	BW_11_job_search	BW_12_job_search_no	BW_8_1_empl_primary7d_kind	BW_11_1_job_search_type	BW_empl_act12m	BW_empl_dk12m	BW_1_1_empl_appr_ever	BW_2_1_empl_farm_ever	BW_3_1_empl_inc_ever	BW_4_1_empl_bus_ever	BW_5_1_empl_fhelp_ever	BW_10_2_empl_status) (ishead	presence	gender	relation	age	age_dk	edu_current	edu_ever	edu_level	occ_lev1	read	write	occ_clerq	occ_craft	occ_elem	occ_forces	occ_mgr	occ_plant	occ_prof	occ_service	occ_skilled	occ_tech	migr_never	migr_time_dk	migr_time_m	migr_time_y	migr_from	migr_oscillation	empl_appr12m	empl_farm12m	empl_inc12m	empl_bus12m	empl_fhelp12m	empl_primary12m	empl_active7d	empl_primary7d	empl7d_inactive	empl7d_temp	job_search	job_search_no	empl_primary7d_kind	job_search_type	empl_act12m	empl_dk12m	empl_appr_ever	empl_farm_ever	empl_inc_ever	empl_bus_ever	empl_fhelp_ever	empl_status) 

********************************************************************************
*Generate number of members per household
********************************************************************************
bys state ea hh: gen hhsize=_N

********************************************************************************
*Generate age grouping variables
********************************************************************************
gen age_cat = age
*Generate and label age group variable
*End with above 49
recode age (0/5 = 1 "Under 6 Years") (6/14 = 2 "6 - 14 Years") (15/65 = 3 "15 - 64 Years") (65/100 = 4 "Above 64 Years"), generate(age_g)
recode age (0/4 = 1 "Under 5 Years") (5/9 = 2 "5 - 9 Years") (10/14 = 3 "10 - 14 Years") (15/19 = 4 "15 - 19 Years") (20/24 = 5 "20 - 24 Years") (25/29 = 6 "25 - 29 Years") (30/34 = 7 "30 - 34 Years") (35/39 = 8 "35 - 39 Years") (40/44 = 9 "40 - 44 Years") (45/49 = 10 "45 - 49 Years") (50/100 = 11 "Above 49 Years"), generate(age_g_alt)
label var age_g "Age Category"
label var age_g_alt "Age Category"
*End with above 80
recode age_cat (0/4 = 1 "Under 5 Years") (5/9 = 2 "5 - 9 Years") (10/14 = 3 "10 - 14 Years") (15/19 = 4 "15 - 19 Years") (20/24 = 5 "20 - 24 Years") (25/29 = 6 "25 - 29 Years") (30/34 = 7 "30 - 34 Years") (35/39 = 8 "35 - 39 Years") (40/44 = 9 "40 - 44 Years") (45/49 = 10 "45 - 49 Years") (50/54 = 11 "50 - 54 Years") (55/59 = 12 "55 - 59 Years") (60/65 = 13 "60 - 64 Years") (65/69 = 14 "65 - 69 Years") (70/74 = 15 "70 - 74 Years") (75/79 = 16 "75 - 79 Years") (80/100 = 17 "Above 80 Years"), generate(age_cat_g)
label var age_cat_g "Age Category"
*Generate and label youth age group variable
gen youth = inrange(age, 15, 35)
recode age (15/20 = 1 "Between 15 and 20 Years") (21/25 = 2 "Between 21 and 25 Years") (26/30 = 3 "Between 26 and 30 Years") (31/35 = 4 "Between 31 and 35 Years") if youth == 1, generate(youthage_g)
label var youth "Youth Age"
label var youthage_g "Youth Age Group"
*Generate and label working age variable
gen working_age = .
replace working_age = 0 if age < 15 & age != .
replace working_age = 0 if age > 64 & age != .
replace working_age = 1 if age >= 15 & age <= 64 & age != .
label var working_age "Working Age"
label val working_age yn

********************************************************************************
*Generate school age grouping variables
********************************************************************************
*Generate and label school age indicator
gen school_age = .
replace school_age = 0 if age < 6
replace school_age = 1 if age >= 6
label var school_age "Of School Age"
*Generate and label primary school age indicator
gen school_age_primary = 0
replace school_age_primary = 0 if age < 6 | age > 18 
replace school_age_primary = 1 if age >= 6 & age <= 13
label var school_age_primary "Of Primary School Age"
*Generate and label secondary school age indicator
gen school_age_secondary = .
replace school_age_secondary = 0 if age < 14 | age > 18
replace school_age_secondary = 1 if age >= 14 & age <= 18
label var school_age_secondary "Of Secondary School Age"
*Generate and label school age indicator
gen school_age_prim_second = .
replace school_age_prim_second = 0 if age < 6 | age > 18
replace school_age_prim_second = 1 if age >= 6 & age <=18
label var school_age_prim_second "Of Primary or Secondary School Age"
*Generate and label post-secondary school age indicator
gen school_age_adult = .
replace school_age_adult = 0 if age < 19
replace school_age_adult = 1 if age >= 19
label var school_age_adult "Of Post-Secondary School Age"
*give variables value labels 
foreach var of varlist school_age school_age_primary school_age_secondary school_age_prim_second school_age_adult {
	label val `var' yn
}
********************************************************************************
*Generate literacy and education status variables
********************************************************************************
*Generate literacy variable (literacy defined as ability to read AND write) and add variable label
gen literacy = .
replace literacy = 0 if read == 0 | write == 0
replace literacy = 1 if read == 1 & write == 1
label var literacy "Literacy" 
label val literacy yn
*Generate education group variable
recode edu_level (0 = 1 "No Education") (11/21 = 2 "Primary & Intermediate") (22/27 = 3 "Secondary") (29/33 = 4 "University") (7 8 = 5 "Others"), generate(edu_level_g)
label var edu_level_g "What is the highest level of education completed (categorized)?"
*Assign those who are less than or equal 5 years old to "Not of Education Age"
replace edu_level_g = 0 if school_age == 0
label define edu_level_g 0 "Not of Education Age" .a "Don't know" .b "Refused to respond", add
*Assign those who have never had education to "No Education"
replace edu_level_g = 1 if edu_ever == 0 & edu_level_g != 0
*Enrollment status
gen enrolled = .
replace enrolled = -1 if age_dk
replace enrolled = 0 if age <= 5
replace enrolled = 1 if edu_current == 1
replace enrolled = 2 if edu_ever == 1 & edu_current == 0
replace enrolled = 3 if edu_ever == 0 & edu_current == 0
label define enrolled -1 "Age unknown" 0 "Not of education age" 1 "Currently enrolled" 2 "Previously enrolled" 3 "Never enrolled"
label values enrolled enrolled
label variable enrolled "Enrollment status"
tab enrolled

********************************************************************************
*Generate occupation and employment status variables
********************************************************************************
*Generate primary occupation variables
gen occ_main = .
replace occ_main = . if edu_current == 0 & occ_lev1 == 0
replace occ_main = 1 if edu_current == 1 & occ_lev1 == 0
replace occ_main = 2 if occ_lev1 == 1 | occ_lev1 == 2 | occ_lev1 == 3
replace occ_main = 3 if occ_lev1 == 4 | occ_lev1 == 5 
replace occ_main = 4 if occ_lev1 == 7 | occ_lev1 == 8 | occ_lev1 == 9
replace occ_main = 5 if occ_lev1 == 10
label def occupation 0 "No Occupation"  1 "Education Only" 2 "Professional Services" 3 "Support Services" 4 "Elementary Occupations" 5 "Armed Forces"
label val occ_main occupation
label var occ_main "Main Occupation" 
tab occ_main
*Generate variable indicating recently active in the labor mkt in past week, 
*defined as either "did something in the last seven days" OR "did not but will definitely return to work"
gen active_7d = .
replace active_7d = 1 if empl_active7d == 1 | empl7d_temp == 1
replace active_7d = 0 if empl_act12m == 0
label var active_7d "Currently working or about to return to work"
lab val active_7d yn
*Generate variable indicating recently active in the labor mkt in past year, defined as either "did something in the last 12 months"
gen active_12m = .
replace active_12m = 0 if (empl_appr12m == 0 & empl_farm12m == 0 & empl_inc12m  == 0 & empl_bus12m  == 0 & empl_fhelp12m == 0)
replace active_12m = 1 if (empl_appr12m == 1 | empl_farm12m == 1 | empl_inc12m  == 1 | empl_bus12m  == 1 | empl_fhelp12m == 1)
label var active_12m "Active in the last year"
label val active_12m yn
*Labor force participation
gen status=0 if inrange(age, 15, 64)
replace status=99 if inlist(age,.,.a,.b)
replace status=3 if status==.
replace status=98 if status ==0 & ((empl_active7d ==.a & inlist(empl7d_temp,.a,.b,.z)) | (empl_active7d ==.b & inlist(empl7d_temp,.a,.b,.z)) | (empl_active7d ==.z & inlist(empl7d_temp,.a,.b,.z)) )
replace status= (empl_active7d == 1 | empl7d_temp == 1) if status ==0 & (!missing(empl_active7d) | !missing(empl7d_temp))
replace status= 2 if status==0 & ((empl_active7d == 0 & empl7d_temp!=1) | (empl7d_temp == 0 & empl_active7d!=1)) & job_search==1
label define status 0 "Inactive" 1 "Employed" 2 "Unemployed"  3 "Outside Working Age" 98 "Working-age, no information on activity" 99 "Age N/A"
label values status status
gen lfparticip = 1 if (empl_active7d == 1 | empl7d_temp == 1) & (working_age == 1)
replace lfparticip = 0 if (working_age == 1 & empl_act12m == 0) | (working_age == 1 & active_7d == 0 & job_search != 1)
replace lfparticip = 1 if (working_age == 1 & active_7d == 0 & job_search == 1)  
replace lfparticip = 0 if (working_age == 1 & active_7d == 0 & job_search != 1)
label def lfparticipl 0 "Outside the labor force / inactive" 1 "In the labor force / active"
label val lfparticip lfparticipl
label var lfparticip "Labor force participation rate"
tab lfparticip
*Check split of active vs inactive
tab active_7d if working_age==1, mis
tab active_12m if working_age==1, mis

********************************************************************************
*Generate master employment/education status variables
********************************************************************************
*Generate employment and education status variable based on activity measure over
*12 month horizon
gen laborchar_12m = .
*Not of working age: less than 15 years old or greater than 64 years old
replace laborchar_12m = 0 if working_age == 0
*Employment only: Active over past year and not enrolled in education
replace laborchar_12m = 4 if working_age == 1 & active_12m == 1 & laborchar_12m != 0 & edu_current == 0 & job_search != . 
*Inactive: Inactive over past year and not currently enrolled in education, and not looking for job
replace laborchar_12m = 5 if working_age == 1 & active_12m == 0 & laborchar_12m != 0 & edu_current == 0 & job_search == 0  
*Education only: Inactive over past year and currently enrolled in education
replace laborchar_12m = 2 if working_age == 1 & active_12m == 0 & laborchar_12m != 0 & edu_current == 1 & job_search != .  
*Education and employment: Active over past year and currently enrolled in education
replace laborchar_12m = 3 if working_age == 1 & active_12m == 1 & laborchar_12m != 0 & edu_current == 1 & job_search != .  
*Unemployed: Inactive over past year, not currently enrolled in education, and looking for job
replace laborchar_12m = 1 if working_age == 1 & active_12m == 0 & laborchar_12m != 0 & edu_current == 0 & job_search == 1  
*Define labels
label var laborchar_12m "Employment & education status"
label def labor 0 "Not of working age"  1 "Unemployed"  2 "Education Only" 3 "Education and Employment" 4 "Employment Only" 5 "Other Inactive" 
label val laborchar_12m labor
tab laborchar_12m if laborchar_12m !=0
tab laborchar_12m if working_age & laborchar_12m & edu_current & job_search & active_12m 

********************************************************************************
*Employment Status of Labor Force Participants
********************************************************************************
*Generate variable
gen laborchar_7d = .
*Set to missing those not of working age
replace laborchar_7d = . if working_age == 0
*Employment only: Active over past seven days and not enrolled in education
replace laborchar_7d = 1 if working_age == 1 & active_7d == 1 & edu_current == 0 
*Employed and Enrolled: Active over past seven days and currently enrolled in education
replace laborchar_7d = 2 if working_age == 1 & active_7d == 1 & edu_current == 1 
*Unemployed: Those not employed in reference period but seeking work over past four weeks
replace laborchar_7d = 3 if working_age == 1 & active_7d == 0 & job_search == 1  
*Define labels
label var laborchar_7d "Status of those participating in the labor force"
label def labor_7d  1 "Employed"  2 "Employment and Enrolled" 3 "Unemployed" 
label val laborchar_7d labor_7d
tab laborchar_7d if laborchar_7d !=0
tab laborchar_7d if working_age & laborchar_7d & edu_current & job_search & active_7d
*Check
tab laborchar_7d
*Same statistics based on 12 month reference period, used to calculate LT UR
*Generate variable
gen laborchar_LT = .
*Set to missing those not of working age
replace laborchar_LT = . if working_age == 0
*Employment only: Active over past seven days and not enrolled in education
replace laborchar_LT = 1 if working_age == 1 & active_12m == 1 & edu_current == 0 
*Employed and Enrolled: Active over past seven days and currently enrolled in education
replace laborchar_LT = 2 if working_age == 1 & active_12m == 1 & edu_current == 1 
*Unemployed: Those not employed in reference period but seeking work over past four weeks
replace laborchar_LT = 3 if working_age == 1 & active_12m == 0 & job_search == 1  
*Define labels
label var laborchar_LT "Status of those participating in the labor force"
label def labor_LT  1 "Employed"  2 "Employment and Enrolled" 3 "Unemployed" 
label val laborchar_LT labor_LT
tab laborchar_LT if laborchar_LT !=0
tab laborchar_LT if working_age & laborchar_LT & edu_current & job_search & active_12m
*Check
tab laborchar_LT

********************************************************************************
*Generate unemployment rate
********************************************************************************
recode laborchar_7d (1/2 = 0 "Employed") (3 = 1 "Unemployed"), gen(u_rate)
label variable u_rate "Unemployment rate"
gen u_rate_LT_ = laborchar_7d  
replace u_rate_LT_ = 4 if laborchar_7d  == 3
recode u_rate_LT_ (1/2 = 0 "Employed") (3 = 1 "Unemployed") (4 = 2 "Long Term Unemployed"), gen(u_rate_LT)
label variable u_rate_LT "Unemployment rate"

********************************************************************************
*Status of those outside the Labor Force 
********************************************************************************
*Generate employment and education status variable
gen whyinactive =  job_search_no
*Set to missing answers that indicate that respondent has or has had job
replace whyinactive = . if (job_search_no == -1 | job_search_no == 7 | job_search_no == 10) 
*Recode others
replace whyinactive = 2 if (job_search_no == 1 & active_7d == 0) & !missing(active_7d, job_search_no)
replace whyinactive = 8 if (job_search_no == 12 & active_7d == 0) & !missing(active_7d, job_search_no)
replace whyinactive = 16 if (job_search_no == 13 & active_7d == 0) & !missing(active_7d, job_search_no)
replace whyinactive = 17 if (job_search_no == 11 | job_search_no == 5 | job_search_no == 0) & active_7d == 0 & !missing(active_7d, job_search_no)
*Make sure to only take into account those outside the labour force
replace whyinactive = . if (active_7d==0) 
*Set recoded values to missing
replace whyinactive = . if inlist(job_search_no,0,1,5,11,12,13)
*Add labels
label var whyinactive "Status of those outside the labor force"
label def whyinactivel 2 "Sick/Disabled" 3 "In school" 4 "Feeling too young/old to work" 6 "Taking care of household" 8 "Waiting for busier season" 9 "Trying to start a business" 10 "Paid leave" 14 "Unpaid volunteer work" 15 "Husband forbids" 16 "Discouraged" 17 "Other" .a "Don't know" .b "Refused to respond"
label val whyinactive whyinactivel
tab whyinactive 

********************************************************************************
*Generate labor force participation variable
********************************************************************************
recode laborchar_12m (0/2 = 0 "Not in the labor force") (3/5 = 1 "In the labor force"), gen(lab_force)
replace lab_force = -2 if laborchar_12m == 0
label define lab_force -2 "Not of working age", add
label variable lab_force "Labor force"

********************************************************************************
*Generate unemployed status variable
********************************************************************************
recode laborchar_7d (1/2 = 0 "Employed") (3 = 1 "Unemployed"), gen(unempl)
label variable unempl "Unemployment status"

********************************************************************************
* Sector Breakdown
********************************************************************************
recode empl_primary7d_kind (11/14 = 1 "Agriculture") (21/25 = 2 "Manufacturing") (26/43 = 3 "Services") (341 = . ), gen(emp_sector_broad)
recode empl_primary7d_kind (11/14 = 1 "Agriculture") (21/25 = 2 "Manufacturing") (26/34 36/43 = 3 "Services") (35 = 4 "Education") (341 = 5 "Defence/Security") (39 = .) , gen(emp_sector_5)

********************************************************************************
* Clean up
********************************************************************************
*Drop unnecessary vars
drop age_cat age_g_alt u_rate_LT u_rate_LT_
*Rename back to original 
rename(ishead	presence	gender	relation	age	age_dk	edu_current	edu_ever	edu_level	occ_lev1	read	write	occ_clerq	occ_craft	occ_elem	occ_forces	occ_mgr	occ_plant	occ_prof	occ_service	occ_skilled	occ_tech	migr_never	migr_time_dk	migr_time_m	migr_time_y	migr_from	migr_oscillation	empl_appr12m	empl_farm12m	empl_inc12m	empl_bus12m	empl_fhelp12m	empl_primary12m	empl_active7d	empl_primary7d	empl7d_inactive	empl7d_temp	job_search	job_search_no	empl_primary7d_kind	job_search_type	empl_act12m	empl_dk12m	empl_appr_ever	empl_farm_ever	empl_inc_ever	empl_bus_ever	empl_fhelp_ever	empl_status)  (B_3_ishead	BB_1_presence	BB_2_gender	BB_3_relation	BB_4_age	BB_4_age_dk	BE_2_edu_current	BE_3_edu_ever	BE_4_edu_level	BE_5_occ_lev1	BE_1_1_read	BE_1_2_write	BE_5_1_occ_clerq	BE_5_1_occ_craft	BE_5_1_occ_elem	BE_5_1_occ_forces	BE_5_1_occ_mgr	BE_5_1_occ_plant	BE_5_1_occ_prof	BE_5_1_occ_service	BE_5_1_occ_skilled	BE_5_1_occ_tech	BM_1_migr_never	BM_2_migr_time_dk	BM_2_migr_time_m	BM_2_migr_time_y	BM_3_migr_from	BM_2_1_migr_oscillation	BW_1_empl_appr12m	BW_2_empl_farm12m	BW_3_empl_inc12m	BW_4_empl_bus12m	BW_5_empl_fhelp12m	BW_6_empl_primary12m	BW_7_empl_active7d	BW_8_empl_primary7d	BW_9_empl7d_inactive	BW_10_empl7d_temp	BW_11_job_search	BW_12_job_search_no	BW_8_1_empl_primary7d_kind	BW_11_1_job_search_type	BW_empl_act12m	BW_empl_dk12m	BW_1_1_empl_appr_ever	BW_2_1_empl_farm_ever	BW_3_1_empl_inc_ever	BW_4_1_empl_bus_ever	BW_5_1_empl_fhelp_ever	BW_10_2_empl_status) 
label var BW_empl_act12m "BW.12 Total number of aforementioned employment activities conducted in the last 12 months"
label var BW_empl_dk12m "BW.12 Total number of aforementioned employment activities did not know"
*Label recoded variables
label var emp_sector_broad "Employment by Sector: Agri, Manu, Serv."
label define emp_sector_broad .a "Don't know" .b "Refused to respond" , modify
label var emp_sector_5 "Employment by Sector: Agri, Manu, Serv, Edu, Def"
label define emp_sector_broad .a "Don't know" .b "Refused to respond" , modify
order BW_8_1_empl_primary7d_kind, a(BW_8_empl_primary7d)
order BM_2_migr_time_m BM_2_1_migr_oscillation, a(BM_2_migr_time_y )
order BW_1_1_empl_appr_ever, a(BW_1_empl_appr12m)
order BW_2_1_empl_farm_ever, a(BW_2_empl_farm12m)
order BW_3_1_empl_inc_ever, a(BW_3_empl_inc12m)
order BW_4_1_empl_bus_ever, a(BW_4_empl_bus12m)
order BW_5_1_empl_fhelp_ever, a(BW_5_empl_fhelp12m)
order BW_10_2_empl_status, a(BW_10_empl7d_temp)
order BW_11_1_job_search_type, a(BW_11_job_search)
ren (BW_empl_act12m BW_empl_dk12m) (BW_12_empl_act12m BW_12_empl_dk12m)

********************************************************************************
*DECLARE SURVEY DATA & SAVE recoded hhm data
********************************************************************************
*Merge sampling weights
merge m:1 state ea hh using "${gsdData}/1-CleanInput/hhq.dta", nogen keepusing(weight urban)
*generate strata
egen stratum = group(state urban)
*Set survey
gen hhweight = weight*hhsize
label var hhweight "Population weight adjusted for hh size"
*Weights are set on household member level 
svyset ea [pweight = hhweight], strata(stratum)
*order hhweight , a(weight)
drop hhweight
order hhsize urban, a(hhmid)
order state stratum
*Save as hhm dataset
save "${gsdData}/1-CleanOutput/hhm.dta", replace
outsheet using "${gsdData}/1-CleanOutput/External/hhm.csv", comma replace
*Reduce label lengths to saveold in STATA version 12
label var BW_2_empl_farm12m 		"BW.2 In the last 12m, did work on the hh's farm, raise the hh"
label var BW_2_1_empl_farm_ever		"BM.2.1 Does ${rhhm_name} join this hh regularly even though they are not"
label var BW_4_empl_bus12m 			"BW.4 In the last 12m, did run a business of any size for themselves or th"
label var BW_5_empl_fhelp12m 		"BW.5 In the last 12m, did help in (not run) any kind of business run by t"
label var BW_7_empl_active7d 		"BW.7 In the last 7d, did ${rhhm_name} do any of the activities mentioned be"
label var BW_9_empl7d_inactive 		"BW.9 Main reason why ${rhhm_name} did not do any activity in the"
label var BW_10_empl7d_temp 		"BW.10 Although ${rhhm_name} did not do any work during the last 7d, does he"
label var BW_12_empl_act12m 		"BW.12 Total number of afrmentnd employment activities conducted in the last"
label var BW_12_empl_dk12m 			"BW.12 Total number of afrmentnd employment activities did not know if he/she"
label var BW_3_1_empl_inc_ever 		"BW.3.1 Has EVER conducted any paid or commissioned work? Please indic., even"
label var BW_5_1_empl_fhelp_ever 	"BW.5.1 Has EVER helped in (not run) any kind of business run by this hh,"
label var BW_10_2_empl_status 		"BW.10.2 What was the main employment status of during their most recent"
*Save as Stata 12 version
saveold "${gsdData}/1-CleanOutput/External/hhm_v12.dta", replace v(12)

********************************************************************************
*Generate household head variables
********************************************************************************
*Rename variables back to recoding names
*Rename back to original 
rename (B_3_ishead	BB_1_presence	BB_2_gender	BB_3_relation	BB_4_age	BB_4_age_dk	BE_2_edu_current	BE_3_edu_ever	BE_4_edu_level	BE_5_occ_lev1	BE_1_1_read	BE_1_2_write	BE_5_1_occ_clerq	BE_5_1_occ_craft	BE_5_1_occ_elem	BE_5_1_occ_forces	BE_5_1_occ_mgr	BE_5_1_occ_plant	BE_5_1_occ_prof	BE_5_1_occ_service	BE_5_1_occ_skilled	BE_5_1_occ_tech	BM_1_migr_never	BM_2_migr_time_dk	BM_2_migr_time_m	BM_2_migr_time_y	BM_3_migr_from	BM_2_1_migr_oscillation	BW_1_empl_appr12m	BW_2_empl_farm12m	BW_3_empl_inc12m	BW_4_empl_bus12m	BW_5_empl_fhelp12m	BW_6_empl_primary12m	BW_7_empl_active7d	BW_8_empl_primary7d	BW_9_empl7d_inactive	BW_10_empl7d_temp	BW_11_job_search	BW_12_job_search_no	BW_8_1_empl_primary7d_kind	BW_11_1_job_search_type	BW_1_1_empl_appr_ever	BW_2_1_empl_farm_ever	BW_3_1_empl_inc_ever	BW_4_1_empl_bus_ever	BW_5_1_empl_fhelp_ever	BW_10_2_empl_status) (ishead	presence	gender	relation	age	age_dk	edu_current	edu_ever	edu_level	occ_lev1	read	write	occ_clerq	occ_craft	occ_elem	occ_forces	occ_mgr	occ_plant	occ_prof	occ_service	occ_skilled	occ_tech	migr_never	migr_time_dk	migr_time_m	migr_time_y	migr_from	migr_oscillation	empl_appr12m	empl_farm12m	empl_inc12m	empl_bus12m	empl_fhelp12m	empl_primary12m	empl_active7d	empl_primary7d	empl7d_inactive	empl7d_temp	job_search	job_search_no	empl_primary7d_kind	job_search_type	empl_appr_ever	empl_farm_ever	empl_inc_ever	empl_bus_ever	empl_fhelp_ever	empl_status)  
*Confirm that every HH has exactly 1 head
bysort state ea hh: egen hhh_indicator = max(ishead)
assert hhh_indicator == 1
drop hhh_indicator
*Generate hhh gender
gen hhh_gender = .
replace hhh_gender = gender if ishead == 1
bysort state ea hh: egen hhh_gender2 = max(hhh_gender)
drop hhh_gender
rename hhh_gender2 hhh_gender
label values hhh_gender hhm_gender
*Recode hhh gender
recode hhh_gender (1 = 0 "Male Head") (2 = 1 "Female Head"), gen(hhh_gender_r)
drop hhh_gender
rename hhh_gender_r hhh_gender
*Generate hhh age
gen hhh_age = .
replace hhh_age = age if ishead == 1
bysort state ea hh: egen hhh_age2 = max(hhh_age)
drop hhh_age
rename hhh_age2 hhh_age
label variable hhh_age "Age of Household Head"
*Generate hhh highest level of education
gen hhh_edu_level_g = .
replace hhh_edu_level_g = edu_level_g if ishead == 1
bysort state ea hh: egen hhh_edu_level_g2 = max(hhh_edu_level_g)
drop hhh_edu_level_g
rename hhh_edu_level_g2 hhh_edu_level_g
label var hhh_edu_level_g "Level of Education of Household Head"
label value hhh_edu_level_g edu_level_g
*For now, set to missing HH heads who are not of education age
replace hhh_edu_level_g = . if hhh_edu_level_g == 0

********************************************************************************
*Generate household level statistics
********************************************************************************

*Compute number of HH members report their age
gen age_nm = .
replace age_nm = 1 if age != .
bysort state ea hh: egen nhhm_age = total(age_nm), missing
drop age_nm
*Compute number of HH members who are (1) of working age and (2) have a non-missing employment status
gen labor_wa = .
replace labor_wa = 0 if laborchar_12m == 0 & laborchar_12m != .
replace labor_wa = 1 if laborchar_12m != 0 & laborchar_12m != .
bysort state ea hh: egen nhhm_labor_wa = total(labor_wa), missing
drop labor_wa
*Compute number of HH members who (1) have a non-missing employment status
gen labor_all = .
replace labor_all = 0 if laborchar_12m == .
replace labor_all = 1 if laborchar_12m != .
bysort state ea hh: egen nhhm_labor_all = total(labor_all), missing
drop labor_all
*Compute employed per household
gen empl = .
replace empl = 0 if unempl == 1
replace empl = 1 if unempl == 0
*Sum employed per household
bysort state ea hh: egen empl_sum = total(empl), missing
*Generate proportion employed to total number of members of working age with non-missing labor status
bysort state ea hh: gen empl_share_wa = empl_sum / nhhm_labor_wa * 100
label var empl_share_wa "Ratio of employed to HH members of working age"
*Generate proportion employed to total number of members with non-missing labor status
bysort state ea hh: gen empl_share_ls = empl_sum / nhhm_labor_all * 100
label var empl_share_ls "Ratio of employed to all HH members with identifiable labor status"
*Generate proportion employed to all members of household
bysort state ea hh: gen empl_share_all = empl_sum / hhsize * 100
label var empl_share_all "Ratio of employed to all HH members"
*Identify dependents (include disabled in dependent indicator)
gen dependent = .
replace dependent = 0 if working_age != . & working_age == 1 & empl7d_inactive != 2
replace dependent = 1 if working_age != . & working_age == 0
replace dependent = 1 if empl7d_inactive != . & empl7d_inactive == 2
*Compute total number of dependents per household
bysort state ea hh: egen ndependents = sum(dependent), missing	
*Create variable that identifies disabled/sick among those of working age
gen disabled = 0 if working_age == 1
replace disabled = 1 if empl7d_inactive != . & empl7d_inactive == 2
tab disabled
*Identify HH members who are not dependents
gen dependent_not = .
replace dependent_not = 0 if dependent == 1
replace dependent_not = 1 if dependent == 0
*Compute HH members who have a non-missing dependency status
bysort state ea hh: egen nindependents = total(dependent_not), missing
*Compute proportion dependents per household
bysort state ea hh: gen depend_share = ndependents / nindependents * 100
label var depend_share "Share of dependents in household"
*Drop unnecessary variables
drop dependent dependent_not

********************************************************************************
*Generate school attendance shares
********************************************************************************
*Compute school attendance shares
foreach l in primary secondary adult prim_second {
	*Count number of HH members that belong to each school age category
	bysort state ea hh: egen school_age_`l'_sum = total(school_age_`l'), missing
	*Generate variable indicating if each HH member attends school for the relevant school age category
	gen attend_`l' = .
	replace attend_`l' = 0 if edu_current==0 & school_age_`l'==1
	replace attend_`l' = 1 if edu_current==1 & school_age_`l'==1
	*Count number of HH members that attend school in each school age category
	bysort state ea hh: egen attend_`l'_sum = total(attend_`l'), missing
	*Compute attendance share for each school age category
	bysort state ea hh: gen attend_`l'_share = attend_`l'_sum / school_age_`l'_sum * 100
	*Label age share variables
	label var attend_`l'_share "School attendance rate of `l' school aged"
	*Drop unnecessary variables
	drop school_age_`l'_sum  attend_`l'_sum
}
********************************************************************************
*Add value labels to yes/no variables
********************************************************************************
*Add value labels for yes/no variables
local yesno "literacy edu_current edu_ever empl_appr12m empl_farm12m empl_inc12m empl_bus12m empl_fhelp12m empl_appr_ever empl_farm_ever empl_inc_ever empl_bus_ever empl_fhelp_ever active_7d active_12m job_search working_age"
foreach var of local yesno {
	label define `var'yn 1 "Yes" 0 "No"
	label val `var' `var'yn
}
********************************************************************************
*DECLARE SURVEY DATA & SAVE recoded hhm data before collapsing
********************************************************************************
*Merge sampling weights
merge m:1 state ea hh using "${gsdData}/1-CleanInput/hhq.dta", nogen keepusing(weight urban)
*Set survey
*Weights are set on household level
svyset ea [pweight = weight], strata(stratum)

********************************************************************************
*Collapse data
********************************************************************************
local collapselist "gender hhsize hhh_age hhh_gender hhh_edu_level_g literacy ndependents nindependents depend_share attend_primary attend_secondary attend_prim_second attend_primary_share attend_secondary_share attend_adult_share attend_prim_second_share"
*Save labels
foreach var of local collapselist {
	*Save variable labels
	local l`var' : variable label `var'
	if `"`l`var''"' == "" {
		local l`var' "`var'"
	}
	*Save value labels
	local vl`var': value label `var'
	if `"`vl`var''"' == "" {
		local vl`var' "` '"
	}
}
*Collapse data
collapse (first) `collapselist', by(state stratum ea hh)
*Reapply labels
foreach var of local collapselist  {
	*Reapply variable labels
	label variable `var' "`l`var''"
	*Reapply value labels
	label value `var' `vl`var''
}
********************************************************************************
*Compute total, urban, and rural dependency ratio 
********************************************************************************
*Merge urban/rural status
merge 1:1 state ea hh using "${gsdData}/1-CleanInput/hhq.dta", assert(match) keep(match master) keepusing(urban) nogenerate
*Compute proportion dependents per household
egen ndependents_total = sum(ndependents), missing
egen nindependents_total = sum(nindependents), missing
gen depend_share_total = ndependents_total / nindependents_total * 100
label var depend_share_total "Share of dependents in sample"
*Compute proportion dependents per household
egen ndependents_urban = sum(ndependents) if urban != . & urban == 1, missing
egen nindependents_urban = sum(nindependents) if urban != . & urban == 1, missing
gen depend_share_urban = ndependents_urban / nindependents_urban * 100
label var depend_share_urban "Share of dependents in urban stratum"
*Compute proportion dependents per household
egen ndependents_rural = sum(ndependents) if urban != . & urban == 0, missing
egen nindependents_rural = sum(nindependents) if urban != . & urban == 0, missing
gen depend_share_rural = ndependents_rural / nindependents_rural * 100
label var depend_share_rural "Share of dependents in rural stratum"

********************************************************************************
*DECLARE SURVEY DATA & SAVE
********************************************************************************
*Merge sampling weights
merge m:1 state ea hh using "${gsdData}/1-CleanInput/hhq.dta", nogen keepusing(weight)
*Set survey
gen hhweight = weight*hhsize
svyset ea [pweight = weight], strata(stratum)
*Add missing variable labels for internal sharing
label var hhh_gender "Gender of Household Head"
label var literacy "Literacy of Household Head"
*Reorder variables for internal sharing
order gender, a(hhsize) 
*Rename variables
ren literacy hhh_literacy
*Sort and order
sort state ea hh 
order ea hh , after(state) 
*Save collapsed and recoded hhm data
save "${gsdData}/1-CleanTemp/hh_hhm.dta", replace

