*This do-file cleans the food consumption data

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
* Load data
use "${gsdData}\1-CleanInput\food.dta", clear

********************************************************************************
* Cleaning: Unit correction
********************************************************************************
* Unit correction: Tag items that are most likely reported in wrong units
gen tag_cons_wrong_u =.
gen tag_purc_wrong_u =.
replace tag_cons_wrong_u =0 if cons!=.
replace tag_purc_wrong_u =0 if cons!=.
* Create loop over units of consumption and purchase, tag and then replace
local ls = "cons purc"
foreach s of local ls{
	* Basin (10 litre): If basin (10 litre) is >= 10, divide by 10 because the 
	* enumerator probably meant litres 
	qui replace tag_`s'_wrong_u = 1 			if  (`s'_q>=10 & `s'_u==1 & cons==1 & cons_q!=.)
	qui replace `s'_q 			= `s'_q/10 		if  (`s'_q>=10 & `s'_u==1 & cons==1 & cons_q!=.)
	* Bundle (100g): If bundle (100g) is >=100, divide by 100 because the 
	* enumerator probably meant grams
	qui replace tag_`s'_wrong_u = 1 			if  (`s'_q>=100 & `s'_u==2 & cons==1  & cons!=.)
	qui replace `s'_q 			= `s'_q/100 	if  (`s'_q>=100 & `s'_u==2 & cons==1  & cons!=.)
	* Cup (200g): If cup (200g) is >= 100, divide by 200 because the enumerator 
	* probably meant grams
	qui replace tag_`s'_wrong_u = 1 			if  (`s'_q>=100 & `s'_u==4 &  cons==1 & cons!=.)
	qui replace `s'_q 			= `s'_q/200 	if  (`s'_q>=100 & `s'_u==4 &  cons==1 & cons!=.)
	* Gram: If grams <=5, multiply by 100 because the enumerator probably meant 
	* kilogram 
	qui replace tag_`s'_wrong_u = 1 			if  (`s'_q<=5 & `s'_u==5  &  cons==1 & cons!=.)
	qui replace `s'_q 			= `s'_q*100 	if  (`s'_q<=5 & `s'_u==5  &  cons==1 & cons!=.)
	* Heap (100g): If heap (100g) is >= 100, divide by 100 because the 
	* enumerator probably meant grams
	qui replace tag_`s'_wrong_u = 1 			if  (`s'_q>=100 & `s'_u==6  & cons==1 & cons!=.)
	qui replace `s'_q 			= `s'_q/100 	if  (`s'_q>=100 & `s'_u==6  & cons==1 & cons!=.)
	* Heap (150g): If heap (150g) is >= 10, divide by 150 because the enumerator 
	* probably meant grams
	qui replace tag_`s'_wrong_u = 1 			if (`s'_q>=100 & `s'_u==7 & cons==1 & cons!=.)
	qui replace `s'_q 			= `s'_q/150 	if (`s'_q>=100 & `s'_u==7 & cons==1 & cons!=.)
	* Heap (300g): If heap (300) is >= 300, divide by 300 because the enumerator 
	* probably meant grams
	qui replace tag_`s'_wrong_u = 1 			if  (`s'_q>=300 & `s'_u==9 & cons==1 & cons!=.)
	qui replace `s'_q 			= `s'_q/300 	if  (`s'_q>=300 & `s'_u==9 & cons==1 & cons!=.)
	* Heap (700g): If heap (700g) is >= 100, divide by 700 because the 
	* enumerator probably meant grams
	qui replace tag_`s'_wrong_u = 1 			if  (`s'_q>=100 & `s'_u==10 & cons==1 & cons!=.)
	qui replace `s'_q 			= `s'_q/700 	if  (`s'_q>=100 & `s'_u==10 & cons==1 & cons!=.)
	* Kilogram: If kilogram > 100, divide by 1,000 because the enumerator 
	* probably meant grams
	qui replace tag_`s'_wrong_u = 1 			if (`s'_q>100 & `s'_u==11 & cons==1 & cons!=.)
	qui replace `s'_q 			= `s'_q/1000 	if (`s'_q>100 & `s'_u==11 & cons==1 & cons!=.)
	* Litre: If litre >=100, divide by 1,000 because the enumerator probably 
	* meant millilitre i.e. grams
	qui replace tag_`s'_wrong_u = 1 			if (`s'_q>=100 & `s'_u==12 & cons==1 & cons!=.)
	qui replace `s'_q 			= `s'_q/1000 	if (`s'_q>=100 & `s'_u==12 & cons==1 & cons!=.)
	* Sack (50kg): If sack (50kg) >= 10, divide by 50 because the enumerator 
	* probably meant kilogram
	qui replace tag_`s'_wrong_u = 1 			if  (`s'_q>=10 & `s'_u==23 & cons==1 & cons!=.)
	qui replace `s'_q 			= `s'_q/50 		if  (`s'_q>=10 & `s'_u==23 & cons==1 & cons!=.)
}

********************************************************************************
* Cleaning: Tag outliers 
********************************************************************************
* Generate new vars that report kg quantities consumed and produced to allow 
* for better comparability
gen cons_q_kg=cons_q*conv2kg_cons
gen purc_q_kg=purc_q*conv2kg_purc
label var cons_q_kg	"Quantity consumed in kg"
label var purc_q_kg "Quantity purchased in kg"
label var item_recall "Recall period"
* Cleaning Rule 1: 
* (i) tag values that were consumed but have missing quantities
gen tag_cons_but_no_q = .
replace tag_cons_but_no_q=0 if (cons!=.) 
replace tag_cons_but_no_q=1 if (cons==1 & cons_q==.)
* (ii) tag values that were consumed and have missing, non-zero purchase values
gen tag_cons_but_no_purc_q = .
replace tag_cons_but_no_purc_q=0 if (cons!=. & purc_q==0) 
replace tag_cons_but_no_purc_q=1 if (cons==1 & purc_q!=0 & purc_q==.)
* (iii) tag values that were purchased but have missing prices
gen tag_purc_but_no_price=.
replace tag_purc_but_no_price=0 if (cons!=.)
replace tag_purc_but_no_price=1 if (cons==1 & price==. & purc_q!=. & purc_q!=0) 
* Cleaning Rule 2: 
* Tag values below or above itemid-unit quantity hard constraints
gen tag_cons_above_hard_q=.
gen tag_purc_above_hard_q=.
gen tag_cons_below_hard_q=.
gen tag_purc_below_hard_q=.
replace tag_cons_above_hard_q=0 if (cons==1)
replace tag_purc_above_hard_q=0 if (cons==1)
replace tag_cons_below_hard_q=0 if (cons==1)
replace tag_purc_below_hard_q=0 if (cons==1)
* Loop over quantities consumed and purchased to tag against hard constraints
rename (c_min_h c_max_h p_min_h p_max_h) (cons_min_h cons_max_h purc_min_h purc_max_h)
local ls = "cons purc"
foreach s of local ls{
	qui replace tag_`s'_below_hard_q = 1 if  (`s'_q<`s'_min_h & cons==1 & `s'_u!=. & `s'_q!=0)
	qui replace tag_`s'_above_hard_q = 1 if  (`s'_q>`s'_max_h & cons==1 & `s'_u!=. & `s'_q!=0)
}
* Cleaning Rule 3: 
* (i) tag values with same figure in quant. consumed, purchased and price
gen tag_cons_purc_price=. 
replace tag_cons_purc_price=0 if (cons==1)
replace tag_cons_purc_price=1 if (cons==1 & cons_q!=.) & (cons_q == purc_q) & (purc_q == price)
* (ii) tag values with same figure for quantity purchased and price
gen tag_purc_price=. 
replace tag_purc_price=0 if (cons==1)
replace tag_purc_price=1 if (cons==1 & cons_q!=.) & (cons_q != purc_q) & (purc_q == price) & (purc_q!=.)
* Cleaning Rule 4: 
* Tag units where records have same figure in cons_q & purc_q, yet != units 
gen tag_same_q_diff_u=.
replace tag_same_q_diff_u=0 if (cons==1)
replace tag_same_q_diff_u=1 if (cons_q==purc_q & cons_u!=purc_u & cons==1 & cons_q!=. & purc_q!=.)
* Cleaning Rule 5: 
* Tag bottom and top 5 percent prices in overall price distributions 
* Convert currencies
gen price_ssp=.
replace price_ssp=price 		if curr==2
replace price_ssp=price*2.95 	if curr==1
* Calculate per kilo price
gen  price_ssp_per_kg = price_ssp/purc_q_kg if cons==1
* Calculate distribution
cumul price_ssp, gen (price_ssp_distribution) equal 
cumul  price_ssp_per_kg, gen ( price_ssp_per_kg_distribution) equal
label define lprice_ssp_tag 1 "Bottom 10% (1)" 2 "Top 10% (2)"
gen tag_price_bottom=.
replace tag_price_bottom=0 if (price_ssp_distribution>=0.05 | price_ssp_distribution<=0.95 |  price_ssp_per_kg>=0.05 |  price_ssp_per_kg>=0.95 ) & (cons==1)
replace tag_price_bottom=1 if (price_ssp_distribution<=0.05 &  price_ssp_per_kg<=0.05 & cons==1 &  price_ssp_per_kg!=.)
gen tag_price_top=.
replace tag_price_top=0	if (price_ssp_distribution>=0.05 | price_ssp_distribution<=0.95 |  price_ssp_per_kg>=0.05 |  price_ssp_per_kg>=0.95 ) & (cons==1)
replace tag_price_top=1	if (price_ssp_distribution>=0.95 &  price_ssp_per_kg>=0.95 & cons==1 &  price_ssp_per_kg!=.)
label values tag_price_bottom ltag_price_bottom
label values tag_price_top ltag_price_top
tab tag_price_bottom
tab tag_price_top
* After investigation (* in loop), tag prices that are in the 95th percentile of 
* the per kilo price distribution beyond which prices are judged to be too high 
local numlist "95"
foreach p of local numlist {
	gen tag_price_top_`p'=.
	replace tag_price_top_`p'=0 if ( price_ssp_per_kg_distribution<=0.`p') & (cons==1) & ( price_ssp_per_kg!=.)
	replace tag_price_top_`p'=1 if ( price_ssp_per_kg_distribution>=0.`p') & (cons==1) & ( price_ssp_per_kg!=.)
	label values tag_price_top ltag_price_top_`p'
	*tab tag_price_top_`p'
	*tabstat  price_ssp_per_kg if tag_price_top_`p'==1 , by(itemlabel) stat(N min mean max) col(stat)
}
* Cleaning Rule 6: 
* Tag items where purc_q_kg == 0 or "." such that cons values can be calculated
gen tag_purc_zero_price = .
replace tag_purc_zero_price = 0 if (cons==1)
replace tag_purc_zero_price = 1 if (cons==1 & purc_q_kg==0) | (cons==1 & purc_q_kg==.) | (cons==1 & cons_q_kg==.)
save "${gsdTemp}/food_temp_2.3.dta", replace

********************************************************************************
* Calculate medians
********************************************************************************
use "${gsdTemp}/food_temp_2.3.dta", clear
* Calculate medians for (i) per kilo prices, (ii) quantities consumed and 
* (iii) quantities purchased on three levels: (i) EA (ii) strata, i.e. 
* state/urban level, (iii) global level; count # of obs available at each level 
* to see how representative the medians are at the respective level
set more off, permanently 
local varlist "price_ssp_per_kg cons_q_kg purc_q_kg"
foreach v of local varlist {
	bysort itemid state ea: egen `v'_ea = median(`v')
	bysort itemid state ea: egen `v'_ea_c = count(`v')
	bysort itemid state urban: egen `v'_state_urban = median(`v')
	bysort itemid state urban: egen `v'_state_urban_c = count(`v')
	bysort itemid : egen `v'_global= median(`v')
}
save "${gsdTemp}/food_temp_2.4.dta", replace

********************************************************************************
* Replace tagged outliers with calculated medians
********************************************************************************
use "${gsdTemp}/food_temp_2.4.dta", clear
* Consumption quantities: replace tagged outliers with medians 
* Use median quantities from smallest geo level where min # of 5/10 obs are available
egen cons_q_kg_median 	= median(cons_q_kg), by(itemid)
local varlist "tag_cons_but_no_q tag_cons_below_hard_q tag_cons_above_hard_q tag_cons_purc_price"
foreach t of local varlist {
	replace  cons_q_kg	 =  cons_q_kg_global if (`t'==1)  										
	replace  cons_q_kg	 =  cons_q_kg_state_urban if (`t'==1 &  cons_q_kg_state_urban_c>=10)
	replace  cons_q_kg	 =  cons_q_kg_ea if (`t'==1 &  cons_q_kg_ea_c>=5)
}
* Purchase quantities: replaced tagged outliers with medians
* Use median quantities from smallest geo level where min # of 5/10 obs are available
local varlist "tag_cons_purc_price tag_cons_but_no_purc_q tag_purc_below_hard_q tag_purc_above_hard_q tag_purc_price " 
foreach t of local varlist {
	replace  purc_q_kg	 =  purc_q_kg_global if (`t'==1)  										
	replace  purc_q_kg	 =  purc_q_kg_state_urban if (`t'==1 &  purc_q_kg_state_urban_c>=10)
	replace  purc_q_kg	 =  purc_q_kg_ea if (`t'==1 &  purc_q_kg_ea_c>=5)
}
* Prices: replace tagged outliers with medians
* Use median prices from smallest geo level where min # of 5/10 obs are available
gen price_ssp_per_kg_cleaned = price_ssp_per_kg if (cons==1) 
local varlist "tag_purc_but_no_price tag_cons_purc_price tag_purc_price tag_price_top_95 tag_purc_zero_price"
foreach t of local varlist{
	replace  price_ssp_per_kg_cleaned	 =  price_ssp_per_kg_global if (`t'==1)  										
	replace  price_ssp_per_kg_cleaned	 =  price_ssp_per_kg_state_urban if (`t'==1 &  price_ssp_per_kg_state_urban_c>=10)
	replace  price_ssp_per_kg_cleaned	 =  price_ssp_per_kg_ea if (`t'==1 &  price_ssp_per_kg_ea_c>=5)
}
* Implement Rule 4: Wrong unit is replaced with unit of correct variabale 
* (consumption or purchase), i.e. the one that is closer to the median in the kg 
* distribution of that variable for the same item (on global level)
bysort itemid: egen cons_kg_median= median(cons_q_kg) 
bysort itemid: egen purc_kg_median= median(purc_q_kg) 
gen diff_cons_kg=abs(cons_q_kg - cons_kg_median) 		if tag_same_q_diff_u==1
gen diff_purc_kg=abs(purc_q_kg - purc_kg_median) 		if tag_same_q_diff_u==1
replace cons_u=purc_u 				if diff_purc_kg<diff_cons_kg & tag_same_q_diff_u==1
replace cons_q_kg=purc_q_kg 		if diff_purc_kg<diff_cons_kg & tag_same_q_diff_u==1
replace conv2kg_cons=conv2kg_purc 	if diff_purc_kg<diff_cons_kg & tag_same_q_diff_u==1
replace purc_u=cons_u 				if diff_purc_kg>diff_cons_kg & tag_same_q_diff_u==1
replace conv2kg_purc=conv2kg_cons   if diff_purc_kg>diff_cons_kg & tag_same_q_diff_u==1
*Conduct a few final, individual corrections
replace cons_q_kg = 50 if cons_q_kg == 2500 & itemid == 10109
replace price_ssp_per_kg_cleaned = 6 if price_ssp_per_kg_cleaned == 60 & itemid == 10109
replace price_ssp_per_kg_cleaned = 6.125 if price_ssp_per_kg_cleaned == 22.05 & itemid == 10724
*add prices for consumed products without prices (upape)
replace price_ssp_per_kg_cleaned = price_ssp_per_kg_ea if missing(price_ssp_per_kg_cleaned) & (cons==1) & (price_ssp_per_kg_ea_c>=5)
replace price_ssp_per_kg_cleaned = price_ssp_per_kg_state_urban if missing(price_ssp_per_kg_cleaned) & (cons==1) & (price_ssp_per_kg_state_urban_c>=10)
replace price_ssp_per_kg_cleaned = price_ssp_per_kg_global if missing(price_ssp_per_kg_cleaned) & (cons==1)
*and same for products with 0 prices because this is due to own production
replace price_ssp_per_kg_cleaned = price_ssp_per_kg_ea if (price_ssp_per_kg_cleaned==0) & (cons==1) & (price_ssp_per_kg_ea_c>=5)
replace price_ssp_per_kg_cleaned = price_ssp_per_kg_state_urban if (price_ssp_per_kg_cleaned==0) & (cons==1) & (price_ssp_per_kg_state_urban_c>=10)
replace price_ssp_per_kg_cleaned = price_ssp_per_kg_global if (price_ssp_per_kg_cleaned==0) & (cons==1)
* Drop redundant variables from above and re-order
drop cons_kg_median purc_kg_median diff_cons_kg diff_purc_kg 
drop *_state* *_median *_top tag* price_ssp_per_kg_global *global* *_ea* *min* *max* price_ssp_distribution price_ssp_per_kg_distribution 
order  state ea urban hh catlabel itemlabel itemid cons cons_q cons_u cons_q conv2kg_cons cons_q_kg purc_q purc_u conv2kg_purc purc_q_kg price price_ssp price_ssp_per_kg price_ssp_per_kg_cleaned
* Labeling all generated variables
label var conv2kg_cons "Conversion_2_kg factor for unit consumed"
label var cons_q_kg	"Quantity consumed in kg"
label var conv2kg_purc "Conversion_2_kg factor for unit purchased"
label var purc_q_kg "Quantity purchased in kg"
label var price_ssp "Price paid in SSP"
label var price_ssp_per_kg "Price paid in SSP per kg"
label var price_ssp_per_kg_cleaned "Price paid in SSP per kg, cleaned"
save "${gsdTemp}/food_clean_3.dta", replace

********************************************************************************
* Consistency checks:  
********************************************************************************
use "${gsdTemp}/food_clean_3.dta", clear
* What do the values look like, post cleaning?
tabstat price_ssp_per_kg_cleaned  price_ssp_per_kg cons_q_kg purc_q_kg, stat(N sd min q p90 p95 p99 max) col(stat)
* There is no data on prices for itemid==10217, blood and blood products
* Check if all conversion factors that need to be constant are constant
tabstat conv2kg_purc, by(purc_u) stat(min q max)
tabstat conv2kg_cons, by(cons_u) stat(min q max)
* Are the distributions of kg prices in SSP paid across food items reasonable?
tabstat  price_ssp_per_kg  price_ssp_per_kg_cleaned, by(itemlabel) stat(N mean min q p90 p95 p99 max) col(stat)
save "${gsdTemp}/food_clean_4.dta", replace

*Fill in zeros for non-consumed items
use "${gsdTemp}/food_clean_4.dta", clear
*Merge mod_hh variable
merge m:1 state ea hh using "${gsdData}/1-CleanInput/hhq.dta", keepusing(mod_hh) keep(match master) assert(match master) nogen
* Calculate SSP kg consumption and purchase values for each observation by 
* multiplying the consumed kg quantity with the price per kg
gen cons_value = .
replace cons_value = cons_q_kg*price_ssp_per_kg_cleaned 
* Differentiate between missing values and zeros before calculating hh aggregates
replace cons_value = 0 if cons_value == . & (mod_hh ==  mod_item )
* Fill in zeros for asked but non-consumed core items
replace cons_value = 0 if cons_value == . & mod_item == 0
* Set cons_values to missing where cons==.
replace cons_value = . if cons==.
* Drop all items that were missing in order to save space 
drop if cons==.
*Drop households without core consumption
bys state ea hh: egen xcons_hh0 = sum(cons_value) if mod_item == 0
bys state ea hh: egen cons_hh0 = max(xcons_hh0)
drop if cons_hh0==0 | missing(cons_hh0)
drop xcons_hh0
preserve
*Temp save for dropping households without core food cons in other datasets
collapse (mean) cons_hh0, by(state ea hh)
save "${gsdData}\1-CleanTemp\cons_hh0.dta", replace
restore
drop cons_hh0
* Add label
label var cons_value "Weekly consumption value in SSP based on quantity consumed and price paid"
save "${gsdData}\1-CleanTemp\food.dta", replace

********************************************************************************
* Calculate hh level aggregates 
********************************************************************************

use "${gsdData}\1-CleanTemp\food.dta", clear
*Calculate weekly hh consumption aggregates for each module
forval i=0/3 {
	*Load food.dta data
	use "${gsdData}\1-CleanTemp\food.dta", clear
	*Collapse on hh level for modules 0-3
	collapse weight mod_item mod_hh (sum) cons_value if mod_item == `i' , by(state ea hh)
	rename cons_value food_opt`i'_hh_wk
	save "${gsdTemp}/food_opt`i'_hh_wk.dta", replace
}
* Merge into one dataset 
use "${gsdTemp}/food_opt0_hh_wk.dta", clear
forval i=1/3{
	merge 1:1 state ea hh using "${gsdTemp}/food_opt`i'_hh_wk.dta", keepusing(food_opt`i'_hh_wk) keep(match master) assert(match master) nogen
}	
save  "${gsdData}/1-CleanTemp/hh_food_no4.dta", replace

*Run do file that calculates module 4 share 
do  "${gsdDo}/1-1-2-1-clean-food_impute_mod4.do"

use "${gsdData}/1-CleanTemp/hh_food_no4.dta", clear
*Add constructed share for module 4 because of erroneous assignment in questionnaire
*The share of module 4 is calculated as a share of the core and based on the 
*NBHS 2009, as shown below in Appendix. The share of module 4 / core is 11.0622%
gen food_opt4_hh_wk = food_opt0_hh_wk * 0.110622 
*Replace missing values with zeros where no items were consumed, but do not assume
*that households did not consume any food at all
replace food_opt1_hh_wk = 0 if food_opt1_hh_wk  == . & mod_hh == 1
replace food_opt2_hh_wk = 0 if food_opt2_hh_wk  == . & mod_hh == 2
replace food_opt3_hh_wk = 0 if food_opt3_hh_wk  == . & mod_hh == 3
*Set to missing any hh's that did not consume any food 
forval i=0/4{
	replace food_opt`i'_hh_wk = . if food_opt0_hh_wk == 0 | missing(food_opt0_hh_wk)
}
*Check for consistency
tabstat food_opt?_hh_wk, stat(n mean)

*Drop redundant variables
drop weight mod_hh 

save "${gsdData}/1-CleanTemp/hh_food.dta", replace 
