*This do-file calculates Laspeyres weights

*although we only use food in the end, we calculate weights also for non-food
*since we use this to impute item consumption
local lis = "food nonfood"
foreach cat of local lis {
	use "${gsdData}/1-CleanTemp/`cat'.dta", clear
	*ensure that food and non-food have the same format
	if ("`cat'"=="food") {
		ren price_ssp_per_kg_cleaned uprice
	}
	else {
		ren price uprice
	}
	keep state ea hh urban weight mod_item mod_hh itemid cons_value uprice
	*add month
	merge m:1 state ea hh using "${gsdData}/1-CleanInput/hhq.dta", nogen keep(match) assert(master match) keepusing(month)
	ren month tm
	*merge months with little data
	replace tm = tm(2015m4) if tm==tm(2015m5)
	replace tm = tm(2015m9) if tm==tm(2015m11)
	*replace tm = tm(2015m9) if inlist(tm,tm(2015m10),tm(2015m11))
	*calculate core and optional module consumption per hh
	bys state ea hh: egen tcore = total(cons_value) if mod_item==0
	bys state ea hh: egen topt = total(cons_value) if mod_item==mod_hh
	reshape wide cons_value uprice, i(state ea hh urban mod_item) j(itemid)
	*add zero consumption
	foreach v of varlist cons_value* {
	replace `v' = 0 if missing(`v') & inlist(mod_item,0,mod_hh)
	}
	reshape long cons_value uprice, i(state ea hh urban mod_item) j(itemid)
	drop if missing(cons_value)
	*calculate item shares relative to core or optional module
	gen denom = min(tcore,topt)
	gen cons_share = cons_value / denom
	*for blood products and camel liver for which there are no prices
	drop if inlist(itemid,10213,10217)
	save "${gsdTemp}/`cat'-share.dta", replace
	collapse (max) mod_item, by(itemid)
	save "${gsdData}/1-CleanTemp/`cat'-mod_item.dta", replace
	*calculate weights: aggregate across households (using hh weights)
	use "${gsdTemp}/`cat'-share.dta", clear
	collapse (mean) cons_share denom [pweight=weight], by(itemid mod_item)
	drop if cons_share==0
	*calculate total denominator for core and all optional modules
	reshape wide denom, i(itemid cons_share) j(mod_item)
	foreach v of varlist denom? {
		egen t`v'= max(`v')
	}
	egen denom = rowmin(denom?)
	egen tdenom = rowtotal(tdenom?)
	drop denom? tdenom?
	*save module specific shares
	ren cons_share cons_m_share
	gen cons_share = cons_m_share * denom / tdenom 
	label var cons_m_share "Share of module consumption"
	label var cons_share "Share of total consumption"
	*calibrate weights to sum up to 1 
	*replace cons_share = cons_share * denom / tdenom
	*check whether calibration worked
	egen x = total(cons_share)
	assert round(x,0.001)==1
	drop x
	*save weights
	save "${gsdData}/1-CleanTemp/`cat'-weights.dta", replace
}
********************************************************************************
*Merge module 4 shares with shares for other modules
********************************************************************************
use "${gsdData}/1-CleanTemp/food-weights.dta", replace
merge 1:1 itemid using "${gsdData}/1-CleanInput/Other/Food_mod4_shares.dta", nogen
drop tmod4
save "${gsdData}/1-CleanTemp/food-weights_mod4.dta", replace

use "${gsdData}/1-CleanTemp/nonfood-weights.dta", replace
merge 1:1 itemid using "${gsdData}/1-CleanInput/Other/NonFood_mod4_shares.dta", nogen
drop tmod4
save "${gsdData}/1-CleanTemp/nonfood-weights_mod4.dta", replace

*calculate median prices per urban/rural + tm
use "${gsdTemp}/food-share.dta", clear
*national for missing
bysort itemid: egen up_all = median(uprice)
collapse (median) uprice [pweight=weight], by(tm urban itemid up_all)
replace uprice = up_all if missing(uprice)
drop up_all
*save for use in calculating wave 2 deflator
export delimited "${gsdTemp}/foodprices_medians_W1.csv" , replace
*reference is July 2015
gen ref = uprice if tm==tm(2015m7) & urban
*propagate to all records
bysort itemid: egen xref = min(ref)
drop ref
*add consumption weights
merge m:1 itemid using "${gsdData}/1-CleanTemp/food-weights.dta", keep(master match) keepusing(cons_share) nogen
*calculate Laspeyres
gen x = cons_share * uprice/xref
collapse (sum) x, by(tm urban)
ren x cons_defl
label var cons_defl "Laspeyres deflator (based on food)"
*expand to cover the merged months
expand 2 if tm==tm(2015m4), gen(new)
replace tm = tm(2015m5) if new
drop new
*expand 2 if tm==tm(2015m9), gen(new)
*replace tm = tm(2015m10) if new
*drop new
expand 2 if tm==tm(2015m9), gen(new)
replace tm = tm(2015m11) if new
drop new
ren tm month
sort month urban
save "${gsdData}/1-CleanTemp/deflator.dta", replace

reshape wide cons_defl, i(month) j(urban)
label var month "Month"
label var cons_defl0 "Deflator Rural"
label var cons_defl1 "Deflator Urban"
export excel using "${gsdOutput}/deflator.xlsx", replace first(varl)
