*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}
use "${gsdData}/1-CleanInput/livestock.dta", clear

********************************************************************************
*Currencies: identification, labelling, and currency conversion
********************************************************************************
* We check the prices specified in 'other' currency relative to those in SSP
tabstat price if curr==3, by(index) stat(n min q max)
tabstat price if curr==1, by(index) stat(n min p5 p10 q p90 p95 max)
* Declare prices for cattle and goats as SSP. Drop price for sheep 
replace curr = . if (curr == 3 & index == 5) | (curr == 3 & index == 7)
replace curr = 1 if (curr == 3 & index == 6) | (curr == 3 & index == 1)

********************************************************************************
*Identify and replace outliers, using constraints in SSP
********************************************************************************
*Tabulate livestock
tabstat raised_q, by(index) stat(n min p5 p10 q p90 p95 max)
*Check for problems of missing values/completeness of the data
tabstat raised_q soldkilled_q given_q bought_q lost_q born_q, stat(n) 
tabstat raised_q soldkilled_q given_q bought_q lost_q born_q, by(index) stat(max) 
tabstat price, by(index) stat(n min p5 p10 q p90 p95 max) 
*Generate outlier indicator for prices, using constraints
gen outlier_price = .
replace outlier_price = 0 if price <= 10000 & price != .
replace outlier_price = 1 if price > 10000 & price != .
* Calculate median prices 
bysort index: egen 	price_med = median(price)
bysort index: egen  price_meda = max(price)
* Replace outlier prices with medians
replace price = price_meda if outlier_price == 1
drop price_med 
*Tag quantity and price outliers
foreach t in raised soldkilled given bought lost born {
	*Generate outlier indicator
	gen beyond_constraint_`t' = .
	replace beyond_constraint_`t' = 0 if `t'_q < c_max_h & `t'_q != .
	replace beyond_constraint_`t' = 1 if `t'_q >= c_max_h & `t'_q != .
	*Generate median quantities
	bysort index: egen `t'_q_med = median(`t'_q)
	bysort index: egen `t'_q_meda = max(`t'_q)
	*Set outliers to median
	replace beyond_constraint_`t' = `t'_q_med if beyond_constraint_`t' == 1
}
*Correct values falsely entered as year born for born_q variable
replace born_q = born_q_med if born_q == 2012 | born_q == 2013 | born_q ==2014
drop *med* *beyond* *outlier*
*Double check cleaned values
tabstat raised_q soldkilled_q given_q bought_q lost_q born_q, by(index) stat(max) 

********************************************************************************
*Convert to USD
********************************************************************************
gen price_usd = . 
replace price_usd = price if curr==2
replace price_usd = price/2.96 if curr == 1 
label var price_usd "How much would you sell ONE animal for on average today, in USD"

********************************************************************************
*Reorder and save as clean output dataset
********************************************************************************
*Reorder 
order state ea weight hh index raise raised_q soldkilled_q given_q given_reason bought_q lost_q lost_reason born_q price curr price_usd c_max_s c_max_h 
*Save dataset
save "${gsdData}/1-CleanOutput/livestock.dta", replace

********************************************************************************
*Save for external users
********************************************************************************
*Sort and save 
sort state ea hh 
save "${gsdData}/1-CleanOutput/livestock.dta", replace
outsheet using "${gsdData}/1-CleanOutput/External\livestock.csv", comma replace
*Save as Stata 12 version
saveold "${gsdData}/1-CleanOutput/External\livestock_v12.dta", replace v(12)
