*This do-file cleans the hh questionnaire and prepares variables for the analysis

*Load hhq data
use "${gsdData}/1-CleanInput/hhq.dta", clear

********************************************************************************
*Create short labels for existing variables that will be used in tables
********************************************************************************
label var state "State of Residence"
label var D_8_cook "D.8 Source of Cooking"
label var D_9_toilet "D.9 Toilet Facilities"
label var D_15_phone_network "D.15 Phone Network"
label var D_19_hunger "D.19 No Food in Past 1 Month"
label var G_P_2_living_standards_poor "G.P.2 Govt performance, improving living standards"
label var G_P_2_creating_jobs "G.P.2 Govt performance, creating jobs"
label var G_P_2_prices_down "G.P.2 Govt performance, keeping prices down"
label var G_P_2_fighting_corruption "G.P.2 Govt performance, fighting corruption"
label var G_P_2_reliable_electricity "G.P.2 Govt performance, providing reliable electricity"
label var G_P_2_water_sanitation "G.P.2 Govt performance, providing water & sanitation"
label var G_P_41_dispute_resolve_police "G.P.4.1 Reason for not going to the police when a dispute occurs"
label var SWB_8_fear_future "SWB.8 Biggest fear, future of South Sudan"
label var mod_hh "Module assigned to household"
label var D_6_water_time_sum "D.6.1 Time spent on getting water"

********************************************************************************
*Generate household density variable (need to merge number of HH members from collapsed and recoded hhm data
********************************************************************************
*merge hhsize from hhm data
merge 1:1 state ea hh using "${gsdData}/1-CleanTemp/hh_hhm.dta" , assert(match) keepusing(hhsize) keep(match master) nogen

*Generate HH room density
gen hhdensity = D_2_rooms_n / hhsize
recode hhdensity (0/0.25 = 1 "More than 4 Individuals Per Room") (0.25/0.5 = 2 "2 - 4 Individuals Per Room") (0.5/1 = 3 "1 - 2 Individuals Per Room") (1/6 = 4 "Less than 1 Individual Per Room"), generate(memperroom)
label var hhdensity "Household Members Per Room"
label var memperroom "Household Members Per Room (Categorized)"
*Generate HH sleeping room density
gen hhdensity_sl = D_3_slrooms_n / hhsize
recode hhdensity_sl (0/0.25 = 1 "More than 4 Individuals Per Bedroom") (0.25/0.5 = 2 "2 - 4 Individuals Per Bedroom") (0.5/1 = 3 "1 - 2 Individuals Per Bedroom") (1/6 = 4 "Less than 1 Individual Per Bedroom"), generate(memperroom_sl)
label var hhdensity_sl "Household Members Per Sleeping Room"
label var memperroom_sl "Household Members Per Sleeping Room (Categorized)"

********************************************************************************
*Generate IDP variable
********************************************************************************
*Generate variable and add value/variable labels
gen idp = .
label define idp 0 "Residential" 1 "IDP"
label values idp idp
label var idp "Household has been internally displaced by Dec 2013 conflict"
*Individuals who did not migrate after Dec 2013 are not IDPs
replace idp = 0 if A_13_migr_dec13 == 0
*Individuals who did migrate after Dec 2013 but not because of the conflict are also not IDPs
replace idp = 0 if A_13_migr_dec13 == 1 & A_14_migr_dec13_cause == 1
*Individuals who did migrate after Dec 2013 because of the conflict are IDPs
replace idp = 1 if A_13_migr_dec13 == 1 & A_14_migr_dec13_cause == 0

********************************************************************************
*Generate access to service variables
********************************************************************************
*Generate water access variables
recode D_5_1_drink_source (2/9 = 1 "Open Water") (1 = 2 "Filtered Water") (9/11 = 3 "Purchased Water"), generate(watersource)
recode D_6_water_time_sum (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), generate(watertime)
label var D_5_1_drink_source  "D.5.1 Drinking water source"
label var D_6_water_time_sum "D.6. Time Spent on Getting Drinking Water"
*Generate cooking variable
recode D_8_cook (9 = 1 "No cooking") (7 = 2 "Grass") (1 = 3 "Firewood") (2 = 4 "Charcoal"), generate(cooking)
label define cooking .a "Don't know" .b "Refused to respond" , modify
label val cooking cooking
label var cooking "D.8 Source of Cooking"
label var D_8_cook "D.8 Source of Cooking"
drop D_8_cook
rename cooking D_8_cook
*Generate sanitation access variable
recode D_9_toilet (6 = 1 "Bush") (5 7 = 2 "Portable Recepticle") (1 2 = 3 "Pit Latrine") (3 4 = 4 "Flush"), generate(sanitation)
label var sanitation "D.9 Toilet Type"
*Generate lighting access variable
recode D_7_light (13 = 1 "No Lighting") (6 7 = 2 "Grass / Firewood") (3/5 8 11 = 3 "Lamp / Candle / Torch") (1 2 12 = 5 "Electricity") (9 = 6 "Solar Power")  , generate(lighting)
label var lighting "D.7 Source of Lighting"
*Generate distance to market variable
replace D_16_tmarket_sum = . if D_16_tmarket_sum == 0
recode D_16_tmarket_sum (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), generate(dist_mkt)
label var dist_mkt "D.16 Nearest Market"
*Generate distance to school variable
replace D_17_tedu_sum = . if D_17_tedu_sum == 0
recode D_17_tedu_sum (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1 - 5 Hours") (300/5000 = 4 "More than 5 Hours"), generate(dist_school)
label var dist_school "D.17 Nearest School"
*Generate distance to health facility variable
replace D_18_thealth_sum = . if D_18_thealth_sum == 0
recode D_18_thealth_sum  (0/30 = 1 "Less than 30 minutes") (30/60 = 2 "30 minutes to 1 hour") (60/300 = 3 "1-5 Hours") (300/8000 = 4 "More than 5 Hours"), generate(dist_health)
label var dist_health "D.18 Nearest Hospital"
*Recode distance variable in terms of hours instead of minutes
foreach v of varlist D_16_tmarket_sum D_17_tedu_sum D_18_thealth_sum {
	replace `v' = `v' / 60	
}
*Relabel distance variables
label var D_16_tmarket_sum "D.16 How long (in hrs) does it usally take to walk (one way) to the closest food market from this dwelling?"
label var D_17_tedu_sum "D.17 How long (in hrs) does it usally take to walk (one way) to the closest primary school from this dwelling?"
label var D_18_thealth_sum "D.18 How long (in hrs) does it usally take to walk (one way) to the nearest health center from this dwelling?"

********************************************************************************
*Generate "corruption" variables
********************************************************************************
*Generate variable indicating reason for not going to the police in the event of a dispute
recode G_P_41_dispute_resolve_police (1 3 = 1 "Expensive or create more problems") (2 4 = 2 "Unreliable or unhelpful") (5 6 = 3 "Untrustworthy or corrupt") (7 = 4 "No police station nearby"), generate(nopolice_g)
label var nopolice_g "G.P.4.1 Reason for not going to the police when a dispute occurs"
*Generate variable indicating biggest fear for South Sudan
recode SWB_8_fear_future (1 3 4 6 = 1 "Civil war, disintegration, insecurity, & ethnic violence") (5 = 2 "Corruption") (7 9 21 22 23 = 3 "Lack of economic opportunities") (8 = 4 "Health and disease problems") (99 = 5 "Other reasons"), generate(fear_g)
label var fear_g "SWB.8. Biggest fear, future of South Sudan"
save "${gsdData}/1-CleanTemp/hhq_cons_noaggregates.dta", replace

********************************************************************************
*add missing values value labels to newly created variables
********************************************************************************
foreach var in watersource watertime sanitation lighting dist_mkt dist_school dist_health nopolice_g fear_g {
	label define `var' .a "Don't know" .b "Refused to respond" , modify
	label val `var' `var'
	tab `var' , m 
}
********************************************************************************
*Add consumption data for food, non-food and assets
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_cons_noaggregates.dta", clear
*Merge consumption data
merge 1:1 state ea hh using "${gsdData}/1-CleanTemp/hh_food.dta", nogen keep(match master) assert(match master)
merge 1:1 state ea hh using "${gsdData}/1-CleanTemp/hh_nonfood.dta", nogen keep(match master) assert(match master)
merge 1:1 state ea hh using "${gsdData}/1-CleanTemp/hh_assets.dta", nogen keep(match master) assert(match master)
drop mod_item
*Set missing values for non-food and assets to zero, if food was consumed
replace nonfood_opt0_hh_wk = 0 if nonfood_opt0_hh_wk == . 
replace nonfood_opt0_hh_wk = . if missing(food_opt0_hh_wk)
replace assets_hh_wk = 0 if assets_hh_wk  == . 
replace assets_hh_wk = . if missing(food_opt0_hh_wk) 
*Consistency check for data completion and data cleanliness
capture: drop nofood 
tabstat nonfood_opt?_hh_wk food_opt?_hh_wk assets_hh_wk , stat(n min max median mean)
*Add remaining labels
forval i=0/4 {
	label var food_opt`i'_hh_wk "HH Food Cons of Opt Mod `i' Weekly"
	label var nonfood_opt`i'_hh_wk "HH Non-Food Cons of Opt Mod `i' Weekly"
}
*Save as temporary file to be used for consistency checks
save "${gsdTemp}/hhq_cons_aggregates_1.dta", replace

********************************************************************************
*DECLARE SURVEY DATA
********************************************************************************
use  "${gsdTemp}/hhq_cons_aggregates_1.dta", clear
*Merge weights
merge 1:1 state ea hh using "${gsdData}/1-CleanTemp/hh_hhm.dta", keepusing(hhsize) keep(match master) assert(match master) nogen
*generate strata variable
egen stratum = group(state urban)
*Set survey
*Weights are set for household level statistics
svyset ea [pweight = weight], strata(stratum)

********************************************************************************
* Preserve, then finalise dataset for internal sharing 
********************************************************************************
*Reorder
order state stratum ea urban hh
order D_8_cook, a(D_7_light)
order A_2_2_hhsid_replace, a(month)
order BF_1_fempl_wage_dk, a(BF_1_fempl_nat)
order BR_2_11_hhm_ewage_curr_sp , a(BR_21_hhm_ewage_dk)
order C_2_1_hhh_birthplace_ssd C_2_2_countyborn, a(C_2_hhh_birthplace)
order C_5_1_hhh_migra_from_region C_5_1_hhh_migra_from_state C_5_2_hhh_migra_from_county, a(C_5_hhh_migra_from)
order C_8_1_hhh_tribe_spec, a(C_8_hhh_tribe)
order D_5_1_drink_source, a(D_5_water_home)
order D_13_1_land_own_gen, a(D_13_land_own_dur_n)
order D_19_1_hunger_coping, a(D_19_hunger)
order L_1_1_move_want_spec, a(L_1_move_want)
order L_2_1_move_to_state L_2_2_move_to_county, a(L_2_move_to_country)
order L_3_1_move_why_multi1 L_3_1_move_why_multi2 L_3_1_move_why_multi3 L_3_1_move_why_multi4, a(L_3_move_why)
order L_4_1_move_return_other1 L_4_1_move_return_other2 L_4_1_move_return_other3 L_4_1_move_return_other4 L_4_1_move_return_other5, a(L_4_move_return)
order LI_2_1_idp_job, a(LI_2_idp_job_c)
order LI_3_1_idp_safe, a(LI_3_idp_safe_c)
order mod_hh, a(hhsize) 
*add deflator
merge m:1 month urban using "${gsdData}/1-CleanTemp/deflator.dta", nogen keep(match) assert(using match) keepusing(cons_defl)
*Save dataset
sort state ea hh, stable
save "${gsdData}/1-CleanTemp/hhq.dta", replace

