*Resposible for this do-file: lparisotto ; reviewer: siqbal, Mario 

*This do-file imputes consumption for those modules not asked to households, 
*computes the poverty measures, and adds imputed consumption values to the 
*food and nonfood datasets.
*For more info on the imputation method, refer to Pape and Mistian (2014)

set more off

*number of imputations
local m = 100

*prepare household member dataset
use "${gsdData}/1-CleanOutput/hhm.dta", clear
gen nchild = BB_4_age<15 if BB_4_age<.
gen nsenior = BB_4_age>64 if BB_4_age<.
gen hhsex = BB_2_gender if B_3_ishead
gen hhempl = active_12m if B_3_ishead
collapse (sum) nchild nsenior (min) hhsex hhempl (count) hhsize = hhmid, by(state stratum ea hh)
label var hhsex "Gender of household head"
label define lhhsex 1 "Male" 2 "Female"
label val hhsex lhhsex
label var hhempl "Is the household head employed"
label define lyesno 0 "No" 1 "Yes"
label values hhempl lyesno
gen pchild = nchild / hhsize
label var pchild "Share of children in household"
gen psenior = nsenior / hhsize
label var psenior "Share of elderly in household"
drop nchild nsenior
save "${gsdData}/1-CleanTemp/hhm-hh.dta", replace

*prepare household dataset
use "${gsdData}/1-CleanTemp/hhq.dta", clear
merge 1:1 state ea hh using "${gsdData}/1-CleanTemp/hhm-hh.dta", keepusing(pchild psenior hhsex hhempl) nogen assert(match)
*harmonize variable names
ren (food_opt0_hh_wk food_opt1_hh_wk food_opt2_hh_wk food_opt3_hh_wk food_opt4_hh_wk) (cons_f0 cons_f1 cons_f2 cons_f3 cons_f4)
ren (nonfood_opt0_hh_wk nonfood_opt1_hh_wk nonfood_opt2_hh_wk nonfood_opt3_hh_wk nonfood_opt4_hh_wk) (cons_nf0 cons_nf1 cons_nf2 cons_nf3 cons_nf4)
ren assets_hh_wk cons_d
*ensure core consumption
assert cons_f0 > 0 | missing(cons_f0) 

*require positive food consumption (otherwise, we assume data is missing)
drop if missing(cons_f0)

*prepare model variables
replace hhempl = 0 if missing(hhempl)
replace hhsex = 1 if hhsex >=.
*sleeping rooms
ren D_3_slrooms_n hhsleep
recode hhsleep (3/90=3) (-9=0)
label define lsleep 0 "None" 1 "1 Room" 2 "2 Rooms" 3 ">2 Rooms", replace
label values hhsleep lsleep
replace hhsleep = 2 if hhsleep>=.
*water
ren D_5_1_drink_source hhwater
recode hhwater (1/3=1) (4=2) (5/9=3) (10/11=4) (-9=4)
label define lwater 1 "Borehole" 2 "Hand pump" 3 "Open Water" 4 "Other"
label values hhwater lwater
replace hhwater = 4 if hhwater>=.
*light
ren lighting hhlight
recode hhlight (1=0) (2=1) (3/4=2) (5/6=3)
label define llight 0 "None" 1 "Grass / Firewood" 2 "Lamp/Candle/Torch" 3 "Electricity", replace
label values hhlight llight
replace hhlight = 2 if hhlight>=.
*toilet
gen hhtoilet = sanitation!=1 if sanitation<.
label var hhtoilet "Does the household have a toilet?"
replace hhtoilet = 0 if sanitation>=.
label values hhtoilet lyesno

*prepare consumption variables
*make sure missing modules have missing consumption
forvalues i = 1/3 {
	assert missing(cons_f`i') if mod_hh!=`i'
	assert missing(cons_nf`i') if mod_hh!=`i'
}
*adjust to per capita per day 
forvalues i = 0/4 {
	replace cons_f`i' = cons_f`i' / hhsize / 7
	replace cons_nf`i' = cons_nf`i' / hhsize / 7
	label var cons_f`i' "Collected food consumption mod `i' pc pd curr SSP"
	label var cons_nf`i' "Collected non-food consumption mod `i' pc pd curr SSP"
	gen mi_cons_f`i' = cons_f`i'
	gen mi_cons_nf`i' = cons_nf`i'
	label var mi_cons_f`i' "Imputed food consumption mod `i' pc pd curr SSP"
	label var mi_cons_nf`i' "Imputed non-food consumption mod `i' pc pd curr SSP"
}
replace cons_d = cons_d / hhsize / 7
gen mi_cons_d = cons_d
label var cons_d "Consumption flow of durables pc pd curr SSP"
label var mi_cons_d "Consumption flow of durables pc pd curr SSP"
*create some aggregates
egen cons_f =  rowtotal(mi_cons_f?)
egen cons_nf =  rowtotal(mi_cons_nf?)
label var cons_f "Collected food consumption pc pd curr SSP"
label var cons_nf "Collected non-food consumption pc pd curr SSP"
xtile pmi_cons_f0 = mi_cons_f0 [pweight=weight], nquantiles(4)
xtile pmi_cons_nf0 = mi_cons_nf0 [pweight=weight], nquantiles(4)
xtile pmi_cons_d = mi_cons_d [pweight=weight], nquantiles(4)
*prepare smaller dataset
keep state stratum ea urban hh mi_cons_* pmi_cons_* cons_* hhsize pchild psenior hhsex hhempl hhwater hhlight hhsleep hhtoilet weight mod_hh
*build model
local model = "hhsize pchild psenior i.hhsex i.hhempl i.hhwater hhlight hhsleep hhtoilet i.urban i.state"
local model = "i.pmi_cons_f0 i.pmi_cons_nf0 `model'"
*create core consumption for comparison
save "${gsdData}/1-CleanTemp/mi-pre.dta", replace

*Run imputation
use "${gsdData}/1-CleanTemp/mi-pre.dta", clear
*MI
mi set wide
mi register imputed mi_cons_f1 mi_cons_f2 mi_cons_f3 mi_cons_nf1 mi_cons_nf2 mi_cons_nf3
mi register regular hh* ea mi_cons_f0 mi_cons_nf0 mi_cons_d state cons_f4 cons_nf4 mi_cons_f4 mi_cons_nf4
*Multi-variate normal imputation using MCMC 
set seed 181820433
mi impute mvn mi_cons_f1 mi_cons_f2 mi_cons_f3 mi_cons_nf1 mi_cons_nf2 mi_cons_nf3 = `model', add(`m') burnin(1000)
save "${gsdTemp}/mi.dta", replace

use "${gsdTemp}/mi.dta", clear
gen hhweight = weight * hhsize
*deflate consumption aggregates and label them as such
local lis = "f nf"
foreach cat of local lis {
	forvalues i = 0/4 {
		mi xeq: replace mi_cons_`cat'`i' = mi_cons_`cat'`i' / cons_defl
		replace cons_`cat'`i' = cons_`cat'`i' / cons_defl
	}
}
forvalues i = 0/4 {
	label var mi_cons_f`i' "Imputed food consumption module `i' pc pd in July 2015 SSP"
	label var cons_f`i' "Food consumption module `i' pc pd in July 2015 SSP"
}
forvalues i = 0/4 {
	label var mi_cons_nf`i' "Imputed nonfood consumption module `i' pc pd in July 2015 SSP"
	label var cons_nf`i' "Non-food consumption module `i' pc pd in July 2015 SSP"
}
mi xeq: replace mi_cons_d = mi_cons_d / cons_defl
replace cons_d = cons_d / cons_defl
label var mi_cons_d "Consumption flow from durables pc pd in July 2015 SSP"
*create sub-aggregates making sure they are non-zero
*iterate over modules
local lis = "f nf"
foreach cat of local lis {
	forvalues i=1/3 {
		*need to take floor to make sure rounding does not result in negative averages
		egen double xtag`cat'`i' = rowtotal(_*_mi_cons_`cat'`i')
		forvalues j=1/`m' {
			*scale up to get average being zero (without losing the variance)
			replace _`j'_mi_cons_`cat'`i' = _`j'_mi_cons_`cat'`i' - floor(xtag`cat'`i'/`m'*10^5)/10^5 if xtag`cat'`i'<0
		}
	}
}
drop xtag*
*recalculate collected aggregates with deflator
drop cons_f cons_nf
egen cons_f =  rowtotal(cons_f*)
egen cons_nf =  rowtotal(cons_nf*)
*create aggregates
mi passive: egen mi_cons_f = rowtotal(mi_cons_f?)
label var mi_cons_f "Imputed food consumption pc pd in July 2015 SSP"
mi passive: egen mi_cons_nf = rowtotal(mi_cons_nf?)
label var mi_cons_nf "Imputed food consumption pc pd in July 2015 SSP" 
egen tc_core = rowtotal(cons_f0 cons_nf0 cons_d)
egen tc_summ = rowtotal(cons_f? cons_nf? cons_d)
mi passive: gen tc_imp = (mi_cons_f + mi_cons_nf + mi_cons_d)
*check that the consumption aggregates add up to total consumption
assert(round((mi_cons_d + mi_cons_f + mi_cons_nf) - tc_imp),0.0001) == 0
label var tc_core "Total consumption based on core pc pd in July 2015 SSP"
label var tc_summ "Total consumption based on summing pc pd in July 2015 SSP"
label var tc_imp "Total consumption based on imputation pc pd in July 2015 SSP"

*Poverty line 1.90 USD in USD PPP (2011)
* The 2011 PPP for SSD is 1/1.543373
* Thus, the 2011 (PPP) poverty line of 1.9/d translates into 1.9/d / 1.543373 = 1.23 USD (current 2011)
* Using the ER of 2.95 in 2011, we receive 3.63 SSP/d in current 2011 terms
* CPI July 2015: 239.906; June 2011: 100.00
* In 2015 terms, this is 3.63/100*239.906 = 8.71 SSP/d
gen plinePPP = 1.9/ 1.543373 * 2.95/100*239.906
label var plinePPP "2011 PPP 1.90 USD Poverty Line in 2015 SSP"
gen pline125PPP = 1.25 / 1.543373 * 2.95/100*239.906
label var pline125PPP "2011 PPP 1.25 USD Poverty Line in 2015 SSP"
gen pline31PPP = 3.1 / 1.543373 * 2.95/100*239.906
label var pline31PPP "2011 PPP 3.1 USD Poverty Line in 2015 SSP"
*calculate poverty
mi passive: gen poorPPP = tc_imp < plinePPP if !missing(tc_imp)
label var poorPPP "Below 2011 1.9 USD PPP poverty line"
mi estimate: mean poorPPP [pweight=hhweight]
mi estimate: mean poorPPP [pweight=hhweight], over(urban)
mi passive: gen poor125PPP = tc_imp < pline125PPP if !missing(tc_imp)
label var poor125PPP "Below 2011 1.25 USD PPP poverty line"
mi estimate: mean poor125PPP [pweight=hhweight]
mi estimate: mean poor125PPP [pweight=hhweight], over(urban)
mi passive: gen poor31PPP = tc_imp < pline31PPP if !missing(tc_imp)
label var poor31PPP "Below 2011 3.1 USD PPP poverty line"
mi estimate: mean poor31PPP [pweight=hhweight]
mi estimate: mean poor31PPP [pweight=hhweight], over(urban)
label define lpoorPPP 0 "Non-poor" 1 "Poor"
label values poorPPP poor125PPP poor31PPP lpoorPPP
save "${gsdTemp}/mi-analysis.dta", replace

*extract data
use "${gsdTemp}/mi-analysis.dta", clear
forvalues i = 1/`m' {
	use "${gsdTemp}/mi-analysis.dta", clear
	mi extract `i', clear	
	gen mi = `i'
	save "${gsdTemp}/mi_`i'.dta", replace
}
*append
clear
forvalues i = 1/`m' {
	append using "${gsdTemp}/mi_`i'.dta"
}
*adjust weights
replace weight=weight/`m'
drop hhweight
label var mi "Imputation number
save "${gsdData}/1-CleanOutput/mi-extract.dta", replace

*analysis on extract dataset
use "${gsdData}/1-CleanOutput/mi-extract.dta", clear
collapse (mean) tc_* poor* mi_cons_f? mi_cons_nf? mi_cons_d mi_cons_f mi_cons_nf cons_defl , by(state stratum urban ea hh hhsize *weight mod_hh pline*)
*check that poverty figures match 
mean poorPPP [pweight=weight*hhsize]
mean poorPPP [pweight=weight*hhsize] , over(urban)
*label consumption aggregates
label var tc_core "Total consumption based on core pc pd in July 2015 SSP"
label var tc_summ "Total consumption based on summing pc pd in July 2015 SSP"
label var tc_imp "Total consumption based on imputation pc pd in July 2015 SSP"
label var poorPPP "Probability being below 1.9 2011 PPP poverty line"
label var poor125PPP "Probability being below 1.25 2011 PPP poverty line"
label var poor31PPP "Probability being below 3.1 2011 PPP poverty line"
label var mi_cons_d "Durables consumption flow pc pd in real July 2015 SSP"
label var mi_cons_f "Mean imputed food consumption pc pd in real July 2015 SSP"
label var mi_cons_nf "Mean imputed non-food consumption pc pd in real July 2015 SSP"
local lis = "f nf"
foreach cat of local lis {
	forvalues i = 1/4{
		label var mi_cons_`cat'`i' "Mean imputed consumption for food module `i'"
		label var mi_cons_`cat'`i' "Mean imputed consumption for nonfood module `i'"
	}
}
order state stratum ea urban hh hhsize
save "${gsdData}/1-CleanTemp/hhq-poverty.dta", replace

*Reshape module aggregates so that a single column identifies all aggregates
local lis = "f nf"
foreach cat of local lis {
	use "${gsdData}/1-CleanTemp/hhq-poverty.dta", clear
	keep state stratum ea weight hh hhsize mod_hh mi_cons_`cat'0 mi_cons_`cat'1 mi_cons_`cat'2 mi_cons_`cat'3 mi_cons_`cat'4
	ren (mi_cons_`cat'*) (x*)
	reshape long x, i(state stratum ea hh) j(mod_item)
	ren x mi_cons_`cat'
	save "${gsdData}/1-CleanTemp/mi_`cat'_collapsed.dta", replace
}
********************************************************************************
* Integrate total imputed consumption into hhq dataset after imputation
********************************************************************************
*Load hhq data
use "${gsdData}/1-CleanTemp/hhq.dta", clear
*Add imputed total consumption aggregates as well as poverty line
merge m:1 state ea hh using "${gsdData}/1-CleanTemp/hhq-poverty.dta", keep(match master) assert(match master) keepusing(mod_hh pline* poor* tc_core tc_summ tc_imp mi_cons_f mi_cons_nf mi_cons_d ) nogenerate
*Generate poor/nonpoor indicator
mean poorPPP [pweight=weight*hhsize]
gen poor = poorPPP>.58 if !missing(tc_imp)
mean poor [pweight=weight*hhsize]
mean poor125PPP [pweight=weight*hhsize]
gen poor125 = poor125PPP>.56 if !missing(tc_imp)
mean poor125 [pweight=weight*hhsize]
gen poor31 = poor31PPP>.57 if !missing(tc_imp)
mean poor31 [pweight=weight*hhsize]
*Calculate quintiles based on imputed total consumption
xtile quintiles_tc = tc_imp [pweight=weight*hhsize], nquantiles(5)
*Label new variables and order
label var poor "Below 1.9 USD PPP 2011 poverty line"
label var poor125 "Below 1.25 USD PPP 2011 poverty line"
label var poor31 "Below 3.1 USD PPP 2011 poverty line"
label define lpoor 0 "NonPoor" 1 "Poor"
label val poor poor125 poor31 lpoor
label var quintiles_tc "Quintiles for imputed consumption"
label define lquintiles_tc 1 "Poorest Quintile" 2 "Q2" 3 "Q3" 4 "Q4" 5 "Richest Quintile"
label values quintiles_tc lquintiles_tc
order plinePPP poorPPP poor pline125PPP poor125PPP poor125 pline31PPP poor31PPP poor31 , after(month)
*Merge hhm aggregates 
merge m:1 state ea hh using "${gsdData}/1-CleanTemp/hh_hhm.dta", nogen keepusing(depend_share) keep(match master) assert(match master)
*drop weekly consumption data from final dataset
drop food_opt?_hh_wk nonfood_opt?_hh_wk assets_hh_wk
*Save dataset
save "${gsdData}/1-CleanOutput/hhq.dta", replace
*Sort and save for external users
sort state ea hh 
save "${gsdData}/1-CleanOutput/hhq.dta", replace
outsheet using "${gsdData}/1-CleanOutput/External/hhq.csv", comma replace
*Save as Stata 12 version
label var Z_6_respondent_attitude "Z.6 How do you (enum.) describe the respdt’s attitude twrd you drng"
saveold "${gsdData}/1-CleanOutput/External/hhq_v12.dta", replace v(12)

********************************************************************************
* Prepare dataset that has rows with all items for each household, incl. mod 4
********************************************************************************

use "${gsdData}/1-CleanOutput/hhq.dta", clear
*Create local macro for food nonfood identifiers
local lis = "food nonfood"
foreach cat of local lis {
	*Create local macro for abbreviated food nonfood identifiers
	local short = cond("`cat'"=="food","f","nf")
	*Load data 
	use "${gsdData}/1-CleanTemp/`cat'.dta", clear
	assert !missing(mod_item)
	*Merge itemid for module 4 items that were not collected
	merge m:1 itemid using "${gsdData}/1-CleanInput/Other/item_modules_`short'.dta", nogen keepusing(itemid mod_item) keep(match using) assert(match using)
	*Use all itemids to reshape first to wide then to long to add module 4 items
	*For now, items from mod 4 will have no household id's since those items were not collected
	keep weight urban cons_value state ea hh itemid mod_hh mod_item 
	replace mod_item = 4 if missing(mod_item)
	reshape wide mod_item cons_value , i(state ea hh mod_hh ) j(itemid) 
	reshape long mod_item cons_value , i(state ea hh mod_hh ) j(itemid) 
	*Distribute mod_item across all records
	bys itemid: egen x = max(mod_item)
	assert x==mod_item if !missing(mod_item)
	replace mod_item = x
	drop x
	assert missing(cons_value) if mod_item==4
	drop if missing(hh)
	*Now merge itemlabel, and catlabel 
	merge m:1 itemid using "${gsdData}/1-CleanInput/Other/item_modules_`short'.dta", nogen keepusing(mod_item itemlabel catlabel) assert(match) 
	*drop blood products and camel liver because never reported
	drop if inlist(itemid,10213,10217)
	*Now add all item share, and save as reshaped file
	merge m:1 itemid using "${gsdData}/1-CleanTemp/`cat'-weights_mod4.dta", nogen keep(match) assert(match master) keepusing(cons_m_share)
	*Temp save
	save "${gsdTemp}/reshaped_`cat'cons.dta", replace
	
********************************************************************************
*Add households imputed cons aggregates for each module to calculate item cons
********************************************************************************
	
	*Load data
	use "${gsdTemp}/reshaped_`cat'cons.dta", clear
	*Merge module consumption aggregates on household level
	merge m:1 state ea hh mod_item using  "${gsdData}/1-CleanTemp/mi_`short'_collapsed.dta", assert(match) keepusing(mi_cons_`short') nogen
	
	*Calculate imputed consumption values based on item shares and module level aggregates
	gen mi_cons_value = . 
	replace mi_cons_value  = cons_m_share * mi_cons_`short' 
	*Check that imputed cons_values sum up to module aggregates
	preserve
	ren mi_cons_value sumcheck
	collapse (sum) sumcheck, by(state ea hh mod_item mi_cons_`short')
	assert round(mi_cons_`short' - sumcheck ,.0001)==0 if !missing(mi_cons_`short')
	restore	
	*Differentiate between imputed and original data
	gen imputed = ( (mod_hh != mod_item & mod_item >0) | (cons_value == .) )
	*Create single cons var consisting of imputed values only where no real data available
	gen x = mi_cons_value  
	replace x = cons_value if (imputed == 0)
	*Tidy up 
	ren (cons_value x) (cons_value_org cons_value_fin)
	drop  *imputed* mi_cons_value *mi_cons*  cons_m_share 
	order state ea weight hh itemid mod_item mod_hh cons_value_org cons_value_fin 
	label var cons_value_fin "`cat' consumption pc pd in July 2015 SSP, imputed and original" 
	label var cons_value_org "`cat' consumption pc pd in July 2015 SSP, original only"  
	label var mod_item "To which module does the item belong?"
	*Temp save data
	save "${gsdData}/1-CleanTemp/`cat'_incl_imp.dta", replace

********************************************************************************
*Integrate into food and non-food datasets
********************************************************************************
	*Load data
	use "${gsdData}/1-CleanTemp/`cat'_incl_imp.dta", clear
	*Add details on consumption and prices, currency, constraints, etc.
	merge m:1 state ea hh itemid using "${gsdData}/1-CleanTemp/`cat'.dta" , keep(match master) assert(master match) force nogen
		*Tidy up 
	sort state ea hh itemid 
	drop cons_value
	order state ea weight hh urban catlabel itemid itemlabel mod_hh mod_item cons_value_org cons_value_fin 

********************************************************************************
*Drop items that have zero or very small consumption values; rescale others	
********************************************************************************
	*Tag all cons_values that are insignificantly small, i.e. below 0.001 SSP pd pc
	gen small = 1 if (cons_value_fin < 0.001)
	replace small = 0 if (cons_value_fin >= 0.001)
	*Scale up other items in hh in order to keep hh aggregates same as before
	*Sum all cons_values for each household
	bys state ea hh: egen sum = sum(cons_value_fin) 
	*Sum small values for each household
	bys state ea hh: egen small_sum = sum(cons_value_fin) if small == 1
	*Distribute small_sum
	bys state ea hh: egen x = max(small_sum)
	drop small_sum 
	ren x small_sum 
	*Sum non-small values of non-small cons_values per hh
	bys state ea hh: egen nonsmall_sum = sum(cons_value_fin) if small == 0 
	*Calculate proportion of each cons_value of nonsmall_sum
	gen prop = cons_value_fin / nonsmall_sum 
	*Now rescale each item according to its proportion
	gen rescaled = cons_value_fin + (prop * small_sum)
	*Check that rescaling has worked
	bys state ea hh: egen sum_rescaled = sum(rescaled)
	assert round(sum_rescaled  - sum,.001)==0 if sum_rescaled!=0
	*Tidy up
	drop cons_value_fin
	ren  rescaled cons_value_fin
	label var cons_value_fin "`cat' consumption pc pd in July 2015 SSP, imputed and original" 
	drop if small == 1
	drop small sum small_sum nonsmall_sum prop  sum_rescaled 
	order cons_value_fin, after(cons_value_org)
	*Save dataset
	save "${gsdData}/1-CleanOutput/`cat'.dta", replace
	saveold "${gsdData}/1-CleanOutput/External/`cat'_v12.dta", replace v(12)
	outsheet using "${gsdData}/1-CleanOutput/External/`cat'.csv", replace comma
}
