* ------------------------------------------------------------------------------
*
*     HIGH FREQUENCY SURVEY 
*     SOUTH SUDAN
*                          
*  		This do file creates all the raw data used for the figures and 
*		tables of the poverty profile. The results are stored as 
*		"Graph-Figures_final.xls" 
*
*		Responsible for the do-file: lparisotto 
*		Reviewer: siqbal
*
*   ----------------------------------------------------------------------------
********************************************************************************
*PREPARE 2015 DATA: MERGE HHQ/HHM
********************************************************************************
use "${gsdData}/1-CleanOutput/hhm.dta", clear
merge m:1 state ea hh using "${gsdData}/1-CleanOutput/hhq.dta", keepusing(quintiles_tc tc_core tc_summ tc_imp plinePPP poorPPP poor urban weight)
*declare survey data
svyset ea [pweight=weight] , strata(stratum)
save "${gsdData}/1-CleanTemp/hhm_create_figures.dta", replace

*Load hhq data
use "${gsdData}/1-CleanOutput/hhq.dta", clear
*Merge household-level variables from recoded/collapsed hhm data 
merge 1:1 state ea hh using "${gsdData}/1-CleanTemp/hh_hhm.dta", assert(match) keep(match master)  nogenerate
gen isQ1 = (quintiles_tc==1)
label define lq1 0 "Q2toQ5" 1 "Q1"
label val isQ1 lq1
gen isQ5 = (quintiles_tc==5)
label define lq5 0 "Q1toQ4" 1 "Q5"
label val isQ5 lq5
*declare survey data
svyset ea [pweight=weight] , strata(stratum)
save "${gsdData}/1-CleanTemp/hhq_create_figures.dta", replace

********************************************************************************
*SAMPLE/POPULATION CHARACTERISTICS
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
*Tabulate enumerator IDs across states (and temporarily shorten state value labels for table)
label define lState_short 82 "NBG", replace
label define lState_short 83 "WBG", add
label define lState_short 84 "LKS", add
label define lState_short 91 "WES", add
label define lState_short 92 "CES", add
label define lState_short 93 "EES", add
label values state lState_short
*Sample size (households) by state & urban/rural status
qui tabout state urban using "${gsdOutput}/Raw-Data 0.xls", c(freq) replace
*Population size (households) by urban/rural status
qui tabout state urban using "${gsdOutput}/Raw-Data 0.xls", svy c(freq) pop append

********************************************************************************
*Figure 1: Population Pyramid
********************************************************************************
*Load hhm data
use "${gsdData}/1-CleanTemp/hhm_create_figures.dta", clear
svydescribe
*Population BB_4_age distribution by gender
qui tabout age_cat_g BB_2_gender using "${gsdOutput}/Raw-Data 1.xls", svy percent c(col se) f(1) replace stats(chi2)
*calculate share of the population under 7 years old
gen under7 = ( BB_4_age < 7 )
label val under7 yn
svy: mean under7 
*calculate share of the population under 16 years old
gen under16 = ( BB_4_age < 16 )
label val under16 yn
svy: mean under16 
*calculate share of the population under 10 years old
gen under10 = ( BB_4_age < 10 )
label val under10 yn
svy: mean under10 

if (${public} == 0 ) {
*Load 2009 data
use "${gsdData}/1-CleanInput/Other/2009_IND_create_figures.dta", clear
svydescribe
*Population BB_4_age distribution by BB_2_gender
qui tabout age_cat_g BB_2_gender using "${gsdOutput}/Raw-Data 1.xls", svy percent c(col se) f(1) append stats(chi2)
}
else {
display "Data from 2009 NBHS Survey is not provided."
}
********************************************************************************
*Figure 2: Household size 
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
svydescribe
*Household size by urban/rural status
qui tabout urban using "${gsdOutput}/Raw-Data 2.xls", svy sum c(mean hhsize lb ub se) npos(col)  f(1)    replace
*Household size by consumption quintiles
qui tabout quintiles_tc using "${gsdOutput}/Raw-Data 2.xls", svy sum c(mean hhsize lb ub se)   npos(col)  f(1) append 
*Household size by poor/nonpoor
qui tabout poor using "${gsdOutput}/Raw-Data 2.xls", svy sum c(mean hhsize lb ub se) npos(col)  f(1) append 
*T-tests for household size
*by urban / rural
svy: mean hhsize , over(urban)
test [hhsize]Rural = [hhsize]Urban
*by income Q1 / not Q1
svy: mean hhsize , over(isQ1)
test [hhsize]Q1 = [hhsize]Q2toQ5
*by incomeQ5 / not Q5
svy: mean hhsize , over(isQ5)
test [hhsize]Q5 = [hhsize]Q1toQ4
*calculate 2009 mean household size
if (${public} == 0) { 
use "${gsdData}/1-CleanInput/Other/2009_HH_create_figures.dta", clear
svydescribe
svy: mean hhsize
}
else {
display "Data from 2009 NBHS survey is not provided."
}
********************************************************************************
*Figure 3: Highest Educational Attrainment and Literacy of Household Head
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
svydescribe
*Highest education of household head by urban/rural status
qui tabout hhh_edu_level_g urban using "${gsdOutput}/Raw-Data 3.xls", svy percent c(col se) ci2col npos(col) replace
*Highest education of household head by consumption quintiles
qui tabout hhh_edu_level_g quintiles_tc using "${gsdOutput}/Raw-Data 3.xls", svy percent c(col se) ci2col npos(col) append
*Highest education of household head by poor/nonpoor
qui tabout hhh_edu_level_g poor using "${gsdOutput}/Raw-Data 3.xls", svy percent c(col se) ci2col npos(col) append
*Load hhm data
*Literacy by urban/rural status
qui tabout hhh_literacy urban using "${gsdOutput}/Raw-Data 3.xls", svy percent c(col se) ci2col npos(col) append
*Literacy by consumption quintiles
qui tabout hhh_literacy quintiles_tc using "${gsdOutput}/Raw-Data 3.xls", svy percent c(col se) ci2col npos(col) append
*Literacy by poor/nonpoor
qui tabout hhh_literacy poor using "${gsdOutput}/Raw-Data 3.xls", svy percent c(col se) ci2col npos(col) append

if (${public} == 0) { 
*Load 2009 hhq data: 
use "${gsdData}/1-CleanInput/Other/2009_HH_create_figures.dta", clear
svydescribe
*Highest education of household head by urban/rural status
qui tabout edu_level_g urban using "${gsdOutput}/Raw-Data 3.xls", svy percent c(col se) ci2col npos(col) append
*Highest education of household head by consumption quintiles
qui tabout edu_level_g quintiles_tc using "${gsdOutput}/Raw-Data 3.xls", svy percent c(col se) ci2col npos(col) append
*Highest education of household head by poor/nonpoor
qui tabout edu_level_g poor using "${gsdOutput}/Raw-Data 3.xls", svy percent c(col se) ci2col npos(col) append

*Load 2012-2014 data: 
use "${gsdData}/1-CleanInput/Other/Panel_create_figures.dta", clear
svydescribe
*Highest edu of hhhead by year
qui tabout hhh_edu_level_g year using "${gsdOutput}/Raw-Data 3.xls", svy percent c(col se) ci2col npos(col) append
}
else {
display "Data from 2009 NBHS survey or Pilot survey is not provided."
}
********************************************************************************
*Figure 4: Primary and Secondary School Attendance and Literacy Rates
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhm_create_figures.dta", clear
svydescribe
*Attendance amongst those aged 6-13 by gender  (Not shown in Poverty Profile)
qui tabout BE_2_edu_current BB_2_gender if (BB_4_age>=6 & BB_4_age<=13) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) replace 
*Attendance amongst those aged 6-13 by urban/rural 
qui tabout BE_2_edu_current urban  if (BB_4_age>=6 & BB_4_age<=13) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append 
*Attendance amongst those aged 6-13 by quintiles
qui tabout BE_2_edu_current quintiles_tc if (BB_4_age>=6 & BB_4_age<=13) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append 
*Attendance amongst those aged 6-13 by poor/non-poor
qui tabout BE_2_edu_current poor if (BB_4_age>=6 & BB_4_age<=13) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append 
*Attendance amongst those aged 14-18 by gender (Not shown in Poverty Profile)
qui tabout BE_2_edu_current BB_2_gender if (BB_4_age>=14 & BB_4_age<=18) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append 
*Attendance amongst those aged 14-18 by urban/rural 
qui tabout BE_2_edu_current urban if (BB_4_age>=14 & BB_4_age<=18) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append 
*Attendance amongst those aged 14-18 by quintiles
qui tabout BE_2_edu_current quintiles_tc if (BB_4_age>=14 & BB_4_age<=18) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append 
*Attendance amongst those aged 14-18 by poor/non-poor
qui tabout BE_2_edu_current poor if (BB_4_age>=14 & BB_4_age<=18) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append

*Figures in the Poverty Profile
*Attendance amongst those aged 6-18 by gender 
qui tabout BE_2_edu_current BB_2_gender if (BB_4_age <=18 & BB_4_age >=6) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append 
*Attendance amongst those aged 6-18 by urban/rural 
qui tabout BE_2_edu_current urban if (BB_4_age <=18 & BB_4_age >=6) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append 
*Attendance amongst those aged 6-18 by quintiles
qui tabout BE_2_edu_current quintiles_tc if (BB_4_age <=18 & BB_4_age >=6) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append 
*Attendance amongst those aged 6-18 by poor/non-poor
qui tabout BE_2_edu_current poor if (BB_4_age <=18 & BB_4_age >=6) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
*Literacy across age groups, by urban/rural
qui tabout BE_1_1_read urban using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
qui tabout BE_1_1_read urban if BB_4_age >= 10 & BB_4_age < 20 using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
qui tabout BE_1_1_read urban if BB_4_age >= 20 & BB_4_age < 30 using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
qui tabout BE_1_1_read urban if BB_4_age >= 30 & BB_4_age < 40 using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
qui tabout BE_1_1_read urban if BB_4_age >= 40 & !missing(BB_4_age) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
*Literacy by gender
qui tabout BE_1_1_read BB_2_gender using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
*Literacy by urban/rural
qui tabout BE_1_1_read urban using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
*Literacy by income quintiles
qui tabout BE_1_1_read quintiles using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
*Literacy by poor/nonpoor
qui tabout BE_1_1_read poor using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append

if (${public} == 0) {
*Load 2009 data
use "${gsdData}/1-CleanInput/Other/2009_IND_create_figures.dta", clear
svydescribe
*Literacy across age groups, by urban/rural
qui tabout BE_1_1_read urban  using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
qui tabout BE_1_1_read urban if BB_4_age >= 10 & BB_4_age < 20 using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
qui tabout BE_1_1_read urban if BB_4_age >= 20 & BB_4_age < 30 using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
qui tabout BE_1_1_read urban if BB_4_age >= 30 & BB_4_age < 40 using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
*(Aroob) Please check how tabout command is dealing with missing values when you specify
qui tabout BE_1_1_read urban if BB_4_age >= 40 & !missing(BB_4_age) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
*School enrollment in 2009: *Attendance amongst those aged 6-18 by gender 
replace edu_current=. if edu_current<0 
qui tabout edu_current BB_2_gender if (BB_4_age >=6 &  BB_4_age <=18)  using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append 
*Attendance amongst those aged 6-18 by urban/rural 
qui tabout edu_current urban if (BB_4_age >=6 &  BB_4_age <=18) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append 
*Attendance amongst those aged 6-18 by quintiles
qui tabout edu_current quintiles_tc if (BB_4_age >=6 &  BB_4_age <=18) using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append 
*Attendance amongst those aged 6-18 by poor/non-poor
qui tabout edu_current poor if (BB_4_age >=6 &  BB_4_age <=18)  using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
*Literacy by gender
qui tabout BE_1_1_read BB_2_gender 	using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
*Literacy by urban/rural
qui tabout BE_1_1_read urban using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
*Literacy by income quintiles
qui tabout BE_1_1_read quintiles using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
*Literacy by poor/nonpoor
qui tabout BE_1_1_read poor using "${gsdOutput}/Raw-Data 4.xls" , svy percent c(col se) npos(col) append
}
else {
display "Data from 2009 NBHS Survey is not provided."
}
********************************************************************************
*Figure 5: Dependency Ratio
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
svydescribe
*Set weights on individual level
svyset ea [pweight=hhweight] , strata(stratum)
*Dependency share by urban/rural status
qui tabout urban using "${gsdOutput}/Raw-Data 5.xls" if !missing(depend_share) , svy sum h3( | Dependency Ratio) c(mean depend_share lb ub se) cibnone format(1) npos(col) replace 
*Dependency share by consumption quintiles
qui tabout quintiles_tc using "${gsdOutput}/Raw-Data 5.xls" if !missing(quintiles_tc)& !missing(depend_share) , svy sum h3( | Dependency Ratio) c(mean depend_share lb ub se) cibnone format(1) npos(col) append 
*Dependency share by poor/nonpoor
qui tabout poor using "${gsdOutput}/Raw-Data 5.xls" if !missing(quintiles_tc) & !missing(depend_share) , svy sum h3( | Dependency Ratio) c(mean depend_share lb ub se) cibnone format(1) npos(col) append 
*T-tests dependency ratio
*by urban / rural
svy: mean depend_share , over(urban)
test [depend_share]Rural = [depend_share]Urban
*by income Q1 / not Q1
svy: mean depend_share , over(isQ1)
test [depend_share]Q1 = [depend_share]Q2toQ5
*by incomeQ5 / not Q5
svy: mean depend_share , over(isQ5)
test [depend_share]Q5 = [depend_share]Q1toQ4

if (${public} == 0) {
*Load data
use "${gsdData}/1-CleanInput/Other/2009_IND_create_figures.dta", clear
svydescribe
*Dependency share by urban/rural status
tabout urban using "${gsdOutput}/Raw-Data 5.xls" if !missing(depend_share) , svy sum h3( | Dependency Ratio) c(mean depend_share lb ub se) cibnone format(1) npos(col) append 
}
else {
display "Data from 2009 NBHS Survey is not provided."
}
********************************************************************************
*Figure 6: Labor
********************************************************************************
*Load hhm data
use "${gsdData}/1-CleanTemp/hhm_create_figures.dta", clear
svydescribe
*Labor Force Participation Rate: In labor forces vs. outside the labor force
qui tabout lfparticip BB_2_gender if working_age == 1 using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) replace 
qui tabout lfparticip urban if working_age == 1 using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout lfparticip quintiles_tc if working_age == 1  using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout lfparticip poor if working_age == 1 using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
*Among the active, what proportions are employed, employed and enrolled, and unemployed
qui tabout laborchar_7d BB_2_gender using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout laborchar_7d urban using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout laborchar_7d quintiles_tc using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout laborchar_7d poor using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
*Among the inactive (those outside the labor force), what are the activities?
*Why not search a job?
qui tabout whyinactive BB_2_gender using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout whyinactive urban using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout whyinactive quintiles_tc using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout whyinactive poor using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append
*Employment by Sector
qui tabout emp_sector_broad BB_2_gender using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout emp_sector_broad urban using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout emp_sector_broad quintiles_tc using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout emp_sector_broad poor using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append
*Employment by employment type
*Recode variable
qui tabout BW_6_empl_primary12m BB_2_gender if lfparticip == 1 using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout BW_6_empl_primary12m urban if lfparticip == 1 using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout BW_6_empl_primary12m quintiles_tc if lfparticip == 1 using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout BW_6_empl_primary12m poor if lfparticip == 1 using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
*Employment by occupation
*Set to missing those without occupation
replace BE_5_occ_lev1  = . if BE_5_occ_lev1  == 0 
qui tabout BE_5_occ_lev1 BB_2_gender using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout BE_5_occ_lev1 urban using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout BE_5_occ_lev1 quintiles_tc using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout BE_5_occ_lev1 poor using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
*Addition: More narrowly defined employment sector
qui tabout emp_sector_5 BB_2_gender using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout emp_sector_5 urban using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout emp_sector_5 quintiles_tc using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout emp_sector_5 poor using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append
*Youth vs. regular Unemployment
*Load 2015 hhm data 
use "${gsdData}/1-CleanTemp/hhm_create_figures.dta", clear
*Create tabouts for unemployment rate of 10-24 years old
svydescribe
keep if BB_4_age >=10 & BB_4_age <= 24 
qui tabout u_rate  BB_2_gender using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout u_rate  urban using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout u_rate  quintiles_tc using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout u_rate  poor using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 

if (${public} == 0) {
*Calculate available employment statistics from 2009: 
*Load data
use "${gsdData}/1-CleanInput/Other/2009_IND_create_figures.dta", replace
svydescribe
*Create tabouts for LF Participation Rate: In vs. outside the labor force
qui tabout lfparticip BB_2_gender if working_age == 1 using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout lfparticip urban if working_age == 1 using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout lfparticip quintiles_tc if working_age == 1  using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout lfparticip poor if working_age == 1 using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
*Create tabouts for employment variable: employed, enrolled and employed vs unem.
qui tabout laborchar_7d BB_2_gender using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout laborchar_7d urban using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout laborchar_7d quintiles_tc using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout laborchar_7d poor using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
*Create tabouts for employment by sector: Agri, Manu, Ser, Edu, Def
qui tabout emp_sector_5 BB_2_gender using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout emp_sector_5 urban using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout emp_sector_5 quintiles_tc using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout emp_sector_5 poor using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append
*Create tabouts for reason why inactive
qui tabout whyinactive BB_2_gender using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout whyinactive urban using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout whyinactive quintiles_tc using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout whyinactive poor using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append
*Create tabouts for unemployment rate of 10-24 years old
keep if BB_4_age >=10 & BB_4_age <= 24 
qui tabout u_rate  BB_2_gender using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout u_rate  urban using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout u_rate  quintiles_tc using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
qui tabout u_rate  poor using "${gsdOutput}/Raw-Data 6.xls" , svy percent c(col se) npos(col) append 
}
else {
display "Data from 2009 NBHS survey is not provided."
}
********************************************************************************
*Figure 7: Hunger statistics
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
svydescribe
*Hunger by urban/rural status
qui tabout D_19_hunger urban using "${gsdOutput}/Raw-Data 7.xls", svy percent c(col se) npos(col) replace
*Hunger by income quintiles
qui tabout D_19_hunger quintiles_tc using "${gsdOutput}/Raw-Data 7.xls", svy percent c(col se) npos(col) append 
*Hunger by poor/nonpoor
qui tabout D_19_hunger poor using "${gsdOutput}/Raw-Data 7.xls", svy percent c(col se) npos(col) append 
*Coping strategies
qui tabout D_19_1_hunger_coping  urban using "${gsdOutput}/Raw-Data 7.xls", svy percent c(col se) npos(col) append
qui tabout D_19_1_hunger_coping  quintiles_tc using "${gsdOutput}/Raw-Data 7.xls", svy percent c(col se) npos(col) append
qui tabout D_19_1_hunger_coping  poor using "${gsdOutput}/Raw-Data 7.xls", svy percent c(col se) npos(col) append

if (${public} == 0) {
*Load panel 2012-2014 data
use "${gsdData}/1-CleanInput/Other/Panel_create_figures.dta", clear
svydescribe
*2013 - 2014 
*Hunger by stratum 
qui tabout D_19_hunger year using "${gsdOutput}/Raw-Data 7.xls", svy percent c(col se) npos(col) append 
}
else {
display "Data from 2012-2012 Pilot survey is not provided."
}
********************************************************************************
*Figure 8: Access to Services 
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
svydescribe
*Distance to market by urban/rural status
qui tabout urban using "${gsdOutput}/Raw-Data 8.xls" , svy sum c(mean D_16_tmarket_sum se) npos(col) replace 
*Distance to school by urban/rural status
qui tabout urban using "${gsdOutput}/Raw-Data 8.xls"  , svy sum c(mean D_17_tedu_sum se) npos(col) append 
*Distance to health by urban/rural status
qui tabout urban using "${gsdOutput}/Raw-Data 8.xls" , svy sum c(mean D_18_thealth_sum se) npos(col) append 
*Distance to market by consumption quintiles
qui tabout quintiles_tc using "${gsdOutput}/Raw-Data 8.xls" , svy sum c(mean D_16_tmarket_sum se) npos(col) append 
*Distance to school by consumption quintiles
qui tabout quintiles_tc using "${gsdOutput}/Raw-Data 8.xls" , svy sum c(mean D_17_tedu_sum se) npos(col) append 
*Distance to health by consumption quintiles
qui tabout quintiles_tc using "${gsdOutput}/Raw-Data 8.xls" , svy sum c(mean D_18_thealth_sum se) npos(col) append 
*Distance to market by nonpoor
qui tabout poor using "${gsdOutput}/Raw-Data 8.xls" , svy sum c(mean D_16_tmarket_sum se) npos(col) append 
*Distance to school by nonpoor
qui tabout poor using "${gsdOutput}/Raw-Data 8.xls" , svy sum c(mean D_17_tedu_sum se) npos(col) append 
*Distance to health by poor/nonpoor
qui tabout poor using "${gsdOutput}/Raw-Data 8.xls" , svy sum c(mean D_18_thealth_sum se) npos(col) append 
*T-tests distance
*Distance to market by urban / rural
svy: mean D_16_tmarket_sum , over(urban)
test [D_16_tmarket_sum]Rural = [D_16_tmarket_sum]Urban
*Distance to school by urban / rural
svy: mean D_17_tedu_sum , over(urban)
test [D_17_tedu_sum]Rural = [D_17_tedu_sum]Urban
*distance to health center by urban / rural
svy: mean D_18_thealth_sum , over(urban)
test [D_18_thealth_sum]Rural = [D_18_thealth_sum]Urban

********************************************************************************
*Figure 9: Access to Sanitation
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
svydescribe
*Toilet by urban/rural status
qui tabout sanitation urban using "${gsdOutput}/Raw-Data 9.xls" , svy percent c(col se) npos(col) replace 
*Toilet by consumption quintiles
qui tabout sanitation quintiles_tc using "${gsdOutput}/Raw-Data 9.xls" , svy percent c(col se) npos(col) append
*Toilet by poor/nonpoor
qui tabout sanitation poor using "${gsdOutput}/Raw-Data 9.xls" , svy percent c(col se) npos(col) append

if (${public} == 0) {
*Load 2009 data
use "${gsdData}/1-CleanInput/Other/2009_HH_create_figures.dta", clear
svydescribe
*Toilet by urban/rural status
qui tabout sanitation urban using "${gsdOutput}/Raw-Data 9.xls" , svy percent c(col se) npos(col) append 
*Toilet by consumption quintiles
qui tabout sanitation quintiles_tc using "${gsdOutput}/Raw-Data 9.xls" , svy percent c(col se) npos(col) append
*Toilet by poor/nonpoor
qui tabout sanitation poor using "${gsdOutput}/Raw-Data 9.xls" , svy percent c(col se) npos(col) append
}
else {
display "Data from the 2009 NBHS survey is not provided."
}
********************************************************************************
*Figure 10: Source of lighting and cooking
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
svydescribe
*Source of light by urban/rural status
qui tabout lighting urban using "${gsdOutput}/Raw-Data 10.xls" , svy percent c(col se) npos(col) replace 
*Source of light by consumption quintiles
qui tabout lighting quintiles_tc using "${gsdOutput}/Raw-Data 10.xls" , svy percent c(col se) npos(col) append
*Source of light by poor/nonpoor
qui tabout lighting poor using "${gsdOutput}/Raw-Data 10.xls" , svy percent c(col se) npos(col) append 
*Related relevant statistics (shown as alternative Figure 10b)
*Source of cooking and source of water by urban/rural status
qui tabout D_8_cook watersource urban using "${gsdOutput}/Raw-Data 10.xls" , svy percent c(col se) npos(col) append 
*Source of cooking and source of water by consumption quintiles
qui tabout D_8_cook watersource quintiles_tc using "${gsdOutput}/Raw-Data 10.xls" , svy percent c(col se) npos(col) append 
*Source of cooking and source of water by poor/nonpoor
qui tabout D_8_cook watersource poor using "${gsdOutput}/Raw-Data 10.xls" , svy percent c(col se) npos(col) append 

if (${public} == 0) {
*Load 2009 data
use "${gsdData}/1-CleanInput/Other/2009_HH_create_figures.dta", clear
svydescribe
*Source of light by urban/rural status
qui tabout lighting urban using "${gsdOutput}/Raw-Data 10.xls" , svy percent c(col se) npos(col) append 
*Source of light by consumption quintiles
qui tabout lighting quintiles_tc using "${gsdOutput}/Raw-Data 10.xls" , svy percent c(col se) npos(col) append
*Source of light by poor/nonpoor
qui tabout lighting poor using "${gsdOutput}/Raw-Data 10.xls" , svy percent c(col se) npos(col) append 
*Related relevant statistics (shown as alternative Figure 10b)
*Source of cooking and source of water by urban/rural status
qui tabout D_8_cook  urban using "${gsdOutput}/Raw-Data 10.xls" , svy percent c(col se) npos(col) append 
*Source of cooking and source of water by consumption quintiles
qui tabout D_8_cook quintiles_tc using "${gsdOutput}/Raw-Data 10.xls" , svy percent c(col se) npos(col) append 
*Source of cooking and source of water by poor/nonpoor
qui tabout D_8_cook poor using "${gsdOutput}/Raw-Data 10.xls" , svy percent c(col se) npos(col) append 
}
else {
display "Data from the 2009 NBHS survey is not provided."
}
********************************************************************************
*Figure 11: Perceptions of Government Performance
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
svydescribe
keep if urban == 1
*Government performance
*Urban/rural
qui tabout G_P_2_living_standards_poor G_P_2_creating_jobs G_P_2_prices_down G_P_2_fighting_corruption G_P_2_maintaing_roads_brigdges G_P_2_reliable_electricity G_P_2_water_sanitation urban using "${gsdOutput}/Raw-Data 11.xls" , svy percent c(col se) npos(col) replace
*Poor/non-poor
qui tabout G_P_2_living_standards_poor G_P_2_creating_jobs G_P_2_prices_down G_P_2_fighting_corruption G_P_2_maintaing_roads_brigdges G_P_2_reliable_electricity G_P_2_water_sanitation poor using "${gsdOutput}/Raw-Data 11.xls" , svy percent c(col se) npos(col) append
*Performance of national institutions 
*Urban/rural
qui tabout G_P_3_improve_lvng_cmnty G_P_3_improve_lvng_crchs G_P_3_improve_lvng_goss G_P_3_improve_lvng_localgv G_P_3_improve_lvng_spla G_P_3_improve_lvng_spss G_P_3_improve_lvng_stategv G_P_31_improve_lvng_bsness G_P_31_improve_lvng_intcmnty G_P_31_improve_lvng_ngos G_P_31_improve_lvng_unagncs G_P_31_improve_lvng_unmiss urban  using "${gsdOutput}/Raw-Data 11.xls" , svy percent c(col se) npos(col) append
*Poor/non-poor 
qui tabout G_P_3_improve_lvng_cmnty G_P_3_improve_lvng_crchs G_P_3_improve_lvng_goss G_P_3_improve_lvng_localgv G_P_3_improve_lvng_spla G_P_3_improve_lvng_spss G_P_3_improve_lvng_stategv G_P_31_improve_lvng_bsness G_P_31_improve_lvng_intcmnty G_P_31_improve_lvng_ngos G_P_31_improve_lvng_unagncs G_P_31_improve_lvng_unmiss poor using "${gsdOutput}/Raw-Data 11.xls" , svy percent c(col se) npos(col) append

if (${public} == 0) {
*Load 2012-2014 data: 
use "${gsdData}/1-CleanInput/Other/Panel_create_figures.dta", clear
svydescribe
*Government performance // By year
qui tabout G_P_2_living_standards_poor G_P_2_creating_jobs G_P_2_prices_down G_P_2_fighting_corruption G_P_2_maintaing_roads_brigdges G_P_2_reliable_electricity G_P_2_water_sanitation year using "${gsdOutput}/Raw-Data 11.xls" , svy percent c(col se) npos(col) append
*Performance of national institutions // By year
qui tabout G_P_3_improve_lvng_cmnty G_P_3_improve_lvng_crchs G_P_3_improve_lvng_goss G_P_3_improve_lvng_localgv G_P_3_improve_lvng_spla G_P_3_improve_lvng_spss  G_P_31_improve_lvng_bsness G_P_31_improve_lvng_intcmnty G_P_31_improve_lvng_ngos G_P_31_improve_lvng_unagncs G_P_31_improve_lvng_unmiss year  using "${gsdOutput}/Raw-Data 11.xls" , svy percent c(col se) npos(col) append
}
else {
display "Data from the 2012-2014 Pilot survey is not provided."
}
********************************************************************************
*Figure 12: Conflict resolution and reasons for not going to the Police
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
svydescribe
*Reason for not going to the police when a dispute occurs (remove stratum 6 because of a single observation in the stratum, meaning that SEs cannot be computed)
qui tabout nopolice_g urban if stratum!=6 using "${gsdOutput}/Raw-Data 12.xls" , svy percent c(col se) npos(col) replace 
*Reason for not going to the police when a dispute occurs
qui tabout nopolice_g quintiles_tc if stratum!=6  using "${gsdOutput}/Raw-Data 12.xls" , svy percent c(col se) npos(col) append 
*Reason for not going to the police when a dispute occurs
qui tabout nopolice_g poor if stratum!=6 using "${gsdOutput}/Raw-Data 12.xls" , svy percent c(col se) npos(col) append 
*G.P.4 If something gets stolen or you have a dispute, who do you usually seek asistance from to resolve the dispute?
qui tabout G_P_4_dispute_resolve  urban using "${gsdOutput}/Raw-Data 12.xls" , svy percent c(col se) npos(col) append
*Reason for not going to the police when a dispute occurs
qui tabout G_P_4_dispute_resolve  quintiles_tc  using "${gsdOutput}/Raw-Data 12.xls" , svy percent c(col se) npos(col) append 
*Reason for not going to the police when a dispute occurs
qui tabout G_P_4_dispute_resolve  poor using "${gsdOutput}/Raw-Data 12.xls" , svy percent c(col se) npos(col) append 

********************************************************************************
*Figure 13: Fear 
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
svydescribe
*Biggest fear, future of South Sudan
qui tabout fear_g urban using "${gsdOutput}/Raw-Data 13.xls" , svy percent c(col se) npos(col) replace 
*Biggest fear, future of South Sudan
qui tabout fear_g quintiles_tc  using "${gsdOutput}/Raw-Data 13.xls" , svy percent c(col se) npos(col) append 
*Biggest fear, future of South Sudan
qui tabout fear_g poor using "${gsdOutput}/Raw-Data 13.xls" , svy percent c(col se) npos(col) append 

if (${public} == 0) {
*Load 2012-2014 data: 
use "${gsdData}/1-CleanInput/Other/Panel_create_figures.dta", clear
svydescribe
*Biggest fear, future of South Sudan
qui tabout fear_g year using "${gsdOutput}/Raw-Data 13.xls" , svy percent c(col se) npos(col) append 
}
else {
display "Data from the 2012-2014 Pilot survey is not provided."
}
********************************************************************************
*Figure 14: Measures of Satisfaction
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
svydescribe
*Satisfaction at the moment: score from 1-10 
qui tabout urban using "${gsdOutput}/Raw-Data 14.xls" , svy sum c(mean SH_1 se) npos(col) replace
qui tabout quintiles_tc using "${gsdOutput}/Raw-Data 14.xls" , svy sum c(mean SH_1 se) npos(col) append
qui tabout poor using "${gsdOutput}/Raw-Data 14.xls" , svy sum c(mean SH_1 se) npos(col) append
*T-tests for current life satisfaction
*by urban / rural
svy: mean SH_1_satisf_life , over(urban)
test [SH_1_satisf_life]Rural = [SH_1_satisf_life]Urban
*by poor / nonpoor
svy: mean SH_1_satisf_life , over(poor)
test [SH_1_satisf_life]NonPoor = [SH_1_satisf_life]Poor
*by income Q1 / not Q1
svy: mean SH_1_satisf_life , over(isQ1)
test [SH_1_satisf_life]Q1 = [SH_1_satisf_life]Q2toQ5
*by incomeQ5 / not Q5
svy: mean SH_1_satisf_life , over(isQ5)
test [SH_1_satisf_life]Q5 = [SH_1_satisf_life]Q1toQ4
*Satisfaction before Dec 2013: score from 1-10 
qui tabout urban using "${gsdOutput}/Raw-Data 14.xls" , svy sum c(mean SH_2 se) npos(col) append
qui tabout quintiles_tc using "${gsdOutput}/Raw-Data 14.xls" , svy sum c(mean SH_2 se) npos(col) append
qui tabout poor using "${gsdOutput}/Raw-Data 14.xls" , svy sum c(mean SH_2 se) npos(col) append
*T-tests for past life satisfaction
*by urban / rural
svy: mean SH_2_satisf_prev , over(urban)
test [SH_2_satisf_prev]Rural = [SH_2_satisf_prev]Urban
*by poor / nonpoor
svy: mean SH_2_satisf_prev , over(poor)
test [SH_2_satisf_prev]NonPoor = [SH_2_satisf_prev]Poor
*by income Q1 / not Q1
svy: mean SH_2_satisf_prev , over(isQ1)
test [SH_2_satisf_prev]Q1 = [SH_2_satisf_prev]Q2toQ5
*by incomeQ5 / not Q5
svy: mean SH_2_satisf_prev , over(isQ5)
test [SH_2_satisf_prev]Q5 = [SH_2_satisf_prev]Q1toQ4
*Comparison SH_1 SH_2
svy: mean SH_1_satisf_life SH_2_satisf_prev
test SH_1_satisf_life = SH_2_satisf_prev
*General Satisfaction: "I am satisfied with my life"
qui tabout SH_7_3 SWB_1 urban using "${gsdOutput}/Raw-Data 14.xls" , svy percent c(col se) npos(col) append
qui tabout SH_7_3 SWB_1 quintiles_tc using "${gsdOutput}/Raw-Data 14.xls" , svy percent c(col se) npos(col) append
qui tabout SH_7_3 SWB_1 poor using "${gsdOutput}/Raw-Data 14.xls" , svy percent c(col se) npos(col) append
*Rating of living conditions in present past and future, rating of economic conditions in present past and future
qui tabout SWB_2 SWB_3 SWB_4 SWB_5 SWB_6 urban using "${gsdOutput}/Raw-Data 14.xls" , svy percent c(col se) npos(col) append
qui tabout SWB_2 SWB_3 SWB_4 SWB_5 SWB_6 quintiles_tc using "${gsdOutput}/Raw-Data 14.xls" , svy percent c(col se) npos(col) append
qui tabout SWB_2 SWB_3 SWB_4 SWB_5 SWB_6 poor using "${gsdOutput}/Raw-Data 14.xls" , svy percent c(col se) npos(col) append

if (${public} == 0) {
*Load Panel data 2012-2013
use "${gsdData}/1-CleanInput/Other/Panel_create_figures.dta", clear
svydescribe
*Rating of living conditions in present past and future, rating of economic conditions in present past and future
qui tabout  SWB_1 SWB_2 SWB_3 SWB_4 SWB_5 SWB_6 year using "${gsdOutput}/Raw-Data 14.xls" , svy percent c(col se) npos(col) append
}
else {
display "Data from the 2012-2014 Pilot survey is not provided."
}
********************************************************************************
*Figure 15: Safety and experience of violence 
********************************************************************************
*Load data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
svydescribe
*Restrict data to urban households only to allow for comparison with Pilot
preserve
keep if urban == 1
 *How safe do you feel from crime and violence when you are alone? Have you been or anyone in your hh been the victom of a violent crime in the last 3m?
qui tabout K_3* K_10* urban using "${gsdOutput}/Raw-Data 15.xls" , svy percent c(col se) npos(col) replace
qui tabout K_3* K_10* quintiles_tc using "${gsdOutput}/Raw-Data 15.xls" , svy percent c(col se) npos(col) append
qui tabout K_3* K_10* poor using "${gsdOutput}/Raw-Data 15.xls" , svy percent c(col se) npos(col) append
restore
qui tabout K_9_increased_violence urban using "${gsdOutput}/Raw-Data 15.xls" , svy percent c(col se) npos(col) append
qui tabout K_9_increased_violence quintiles_tc using "${gsdOutput}/Raw-Data 15.xls" , svy percent c(col se) npos(col) append
qui tabout K_9_increased_violence poor using "${gsdOutput}/Raw-Data 15.xls" , svy percent c(col se) npos(col) append
 *How safe do you feel from crime and violence when you are alone? Have you been or anyone in your hh been the victom of a violent crime in the last 3m?
qui tabout K_3* K_10* urban using "${gsdOutput}/Raw-Data 15.xls" , svy percent c(col se) npos(col) append
qui tabout K_3* K_10* quintiles_tc using "${gsdOutput}/Raw-Data 15.xls" , svy percent c(col se) npos(col) append
qui tabout K_3* K_10* poor using "${gsdOutput}/Raw-Data 15.xls" , svy percent c(col se) npos(col) append

********************************************************************************
*Figure 16: Poverty: headcount ratio, depth and severity 
********************************************************************************
*Load hhq data
use "${gsdData}/1-CleanTemp/hhq_create_figures.dta", clear
*Set survey to incorporate hhsize since stats are based on population, not hh's
svyset ea [pweight=hhweight], strata(stratum)
svydescribe
*Poverty headcount ratio: % of Population living on $1.90 PPP per person per day
qui tabout poor using "${gsdOutput}/Raw-Data 16.xls" , svy c(mean se lb ub) npos(col) f(4) replace
qui tabout urban using "${gsdOutput}/Raw-Data 16.xls" , svy sum c(mean poor se lb ub) npos(col) f(4) append
qui tabout hhh_gender using "${gsdOutput}/Raw-Data 16.xls" , svy sum c(mean poor se lb ub) npos(col) f(4)  append
*Poverty gap/depth: mean aggregate income relative to poverty line
*Calculate gap in SSP
gen gap = (plinePPP - tc_imp)/plinePPP if (!missing(tc_imp)) 
replace gap = 0 if (tc_imp>plinePPP & !missing(tc_imp))
*test mean difference in poverty gap by urban/rural
svy: mean gap , over(urban)
test [gap]Rural = [gap]Urban
*Calculate mean poverty gaps for urban/rural
qui tabout urban using "${gsdOutput}/Raw-Data 16.xls" , svy sum c(mean gap se lb ub) npos(col) f(4) append
*Calculate mean poverty gap for female/male-headed households
qui tabout hhh_gender  using "${gsdOutput}/Raw-Data 16.xls" , svy sum c(mean gap se lb ub) npos(col) f(4) append
*Poverty severity: squared poverty gap to capture inequality among the poor 
gen severity = (gap)^2
*test difference of means of severity by urban/rural
svy: mean severity , over(urban)
test [severity]Rural = [severity]Urban
*test difference of means of severity by urban/rural
svy: mean severity , over(hhh_gender)
test [severity]_subpop_1  = [severity]_subpop_2
*Calculate mean poverty severity for urban/rural
qui tabout urban using "${gsdOutput}/Raw-Data 16.xls" , svy sum c(mean severity se lb ub) npos(col) f(4) append
*Calculate mean poverty severity for female/male-headed households
qui tabout hhh_gender  using "${gsdOutput}/Raw-Data 16.xls" , svy sum c(mean severity se lb ub) npos(col) f(4) append

if (${public} == 0) {
use "${gsdData}/1-CleanInput/Other/2009_HH_create_figures.dta", clear
*Set survey to incorporate hhsize since stats are based on population, not hh's
svyset cluster [pweight=hhweight], strata(stratum)
svydescribe
*Poverty headcount
qui tabout urban using "${gsdOutput}/Raw-Data 16.xls" , svy sum c(mean poor se lb ub) npos(col) f(4) append
qui tabout head_sex using "${gsdOutput}/Raw-Data 16.xls" , svy sum c(mean poor se lb ub) npos(col) f(4)  append
}
else {
display "Data from the 2009 NBHS survey is not provided."
}

********************************************************************************
*Combining of the various sheets into one Excel file
********************************************************************************

forv i=0/16 {
	insheet using "${gsdOutput}/Raw-Data `i'.xls", clear nonames
	export excel using "${gsdOutput}/Graph-Figures_final.xlsx", sheetreplace sheet("Raw data for Figure `i'") 
*	rm "${gsdOutput}/Raw-Data `i'.xls"
}

