*-------------------------------------------------------------------
*
*     HIGH FREQUENCY SURVEY 
*     SOUTH SUDAN
*     
*     This file contains the sequence of do-files
*     written to carry out the poverty analysis
*     for South Sudan 2015
*                         
*-------------------------------------------------------------------

clear all
set more off
set maxvar 10000

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

****************************************************************
* Process the raw data
****************************************************************
*If processraw is set to 0, all raw data processing will be skipped, and only
* the clean and analysis do files will be run
*If processraw is set to 1, all do files processing the raw data will be run. 
local processraw = 0

* Import, clean, and validate Phase 1, May, and Phase 2 raw data
if (`processraw'==1) {

	*The Phase 1 food and non-food processing file involves a (lengthy) reshape of 
	*the data from wide to long. To skip this step, set quickrun to 1; otherwise, set to 0.
	global quickrun = 0

	*Begin cleaning the Phase 1, May, and Phase 2 raw data
	foreach phase in Phase1 May Phase2 {
		*Within each phase, execute the sequence of do files that clean the raw data
		local i=0
		foreach sf in import hhq hhm duplicates foodandnonfood livestock assets assert {	
			local i=`i'+1
			do "${gsdDo}/0-cleanraw-`phase'/0-`i'-`sf'.do"
		}
	}

	* Append raw data, run consistency checks, and compute sampling weights
	*Append raw data
	do "${gsdDo}/0-0-append.do"
	*Run consistency checks
	do "${gsdDo}/0-1-consistencychecks.do"
	*Generate sampling weights and incorporate into hhq data
	do "${gsdDo}/0-2-weightcalc.do"

	*Generate anonymized household, EA, and enumerator IDs and apply to all sets of appended data
	do "${gsdDo}/0-3-anonymize.do"

	* Prepare sharable input files
	*Run prepare files
	do "${gsdDo}/0-4-0-prepare.do"
}
****************************************************************
* Recode anonymized hhq and hhm data, clean consumption data
****************************************************************
* clean the data
do "${gsdDo}/1-1-0-clean.do"
* Impute total consumption 
do "${gsdDo}/1-2-0-consaggr-mi.do"

****************************************************************
* Carry out the Analysis 
****************************************************************
*If public is set to 1, the parts of the analysis involving data from the 2009 
*NBHS survey and from the Pilot survey will be skipped, as those datasets are 
*not provided with these files.
global public = 1

* Analysis: Create figures for poverty note
do "${gsdDo}/2-1-analysis-createfigures.do"
